@@ -1,16 +1,16 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-  * Copyright by the Board of Trustees of the University of Illinois.         *
-  * All rights reserved.                                                      *
-  *                                                                           *
-  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
-  * terms governing use, modification, and redistribution, is contained in    *
-  * the files COPYING and Copyright.html.  COPYING can be found at the root   *
-  * of the source code distribution tree; Copyright.html can be found at the  *
-  * root level of an installed copy of the electronic HDF5 document set and   *
-  * is linked from the top-level documents page.  It can also be found at     *
-  * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
-  * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
-  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at the  *
+ * root level of an installed copy of the electronic HDF5 document set and   *
+ * is linked from the top-level documents page.  It can also be found at     *
+ * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
+ * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include <string>
 #ifdef OLD_HEADER_FILENAME
@@ -43,11 +43,11 @@ namespace H5 {
 ///\param	predefined  - IN: Indicates whether or not this datatype is
 ///		a predefined datatype; default to \c false
 // Description
-//		Constructor creates a copy of an existing DataType using 
-//		its id.  The argument "predefined" is default to false; 
-//		when a default datatype is created, this argument is set 
-//		to true so H5Tclose will not be called on it later. - need 
-//		a reassessment after changing to the new ref counting mech. 
+//		Constructor creates a copy of an existing DataType using
+//		its id.  The argument "predefined" is default to false;
+//		when a default datatype is created, this argument is set
+//		to true so H5Tclose will not be called on it later. - need
+//		a reassessment after changing to the new ref counting mech.
 //		- BMR 5/2004
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -65,7 +65,7 @@ DataType::DataType( const H5T_class_t type_class, size_t size ) : H5Object(), is
 {
    // Call C routine to create the new datatype
    id = H5Tcreate( type_class, size );
-   if( id <= 0 )
+   if( id < 0 )
    {
       throw DataTypeIException("DataType constructor", "H5Tcreate failed");
    }
@@ -95,8 +95,8 @@ DataType::DataType(const DataType& original) : H5Object(original)
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
 // Modification
-//              Replaced resetIdComponent with decRefCount to use new ID
-//              reference counting mechanisms by QAK, Feb 20, 2005
+//		Replaced resetIdComponent with decRefCount to use C library
+//		ID reference counting mechanism - BMR, Feb 20, 2005
 //--------------------------------------------------------------------------
 void DataType::copy( const DataType& like_type )
 {
@@ -107,15 +107,15 @@ void DataType::copy( const DataType& like_type )
             decRefCount();
         }
         catch (Exception close_error) {
-            throw DataTypeIException("DataType::copy", close_error.getDetailMsg());
+            throw DataTypeIException(inMemFunc("copy"), close_error.getDetailMsg());
         }
     }
 
    // call C routine to copy the datatype
    id = H5Tcopy( like_type.getId() );
 
-   if( id <= 0 )
-      throw DataTypeIException("DataType::copy", "H5Tcopy failed");
+   if( id < 0 )
+      throw DataTypeIException(inMemFunc("copy"), "H5Tcopy failed");
 }
 
 //--------------------------------------------------------------------------
@@ -125,8 +125,8 @@ void DataType::copy( const DataType& like_type )
 ///\return	Reference to DataType instance
 ///\exception	H5::DataTypeIException
 // Description
-// 		Makes a copy of the type on the right hand side and stores 
-//		the new id in the left hand side object.  
+// 		Makes a copy of the type on the right hand side and stores
+//		the new id in the left hand side object.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 DataType& DataType::operator=( const DataType& rhs )
@@ -137,7 +137,7 @@ DataType& DataType::operator=( const DataType& rhs )
 
 //--------------------------------------------------------------------------
 // Function:	DataType::operator==
-///\brief	Compares this DataType against the given one to determines 
+///\brief	Compares this DataType against the given one to determines
 ///		whether the two objects refer to the same actual datatype.
 ///\param	compared_type - IN: Reference to the datatype to compare
 ///\return	true if the datatypes are equal, and false, otherwise.
@@ -146,7 +146,7 @@ DataType& DataType::operator=( const DataType& rhs )
 //--------------------------------------------------------------------------
 bool DataType::operator==(const DataType& compared_type ) const
 {
-   // Call C routine H5Tequal to determines whether two datatype 
+   // Call C routine H5Tequal to determines whether two datatype
    // identifiers refer to the same datatype
    htri_t ret_value = H5Tequal( id, compared_type.getId() );
    if( ret_value > 0 )
@@ -155,14 +155,14 @@ bool DataType::operator==(const DataType& compared_type ) const
       return false;
    else
    {
-      throw DataTypeIException("DataType::operator==", 
+      throw DataTypeIException(inMemFunc("operator=="),
 		"H5Tequal returns negative value");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::commit
-///\brief	Commits a transient datatype to a file, creating a new 
+///\brief	Commits a transient datatype to a file, creating a new
 ///		named datatype
 ///\param	loc - IN: Either a file or a group
 ///\param	name - IN: Name of the datatype
@@ -173,18 +173,18 @@ void DataType::commit(CommonFG& loc, const char* name) const
 {
    hid_t loc_id = loc.getLocId(); // get location id for C API
 
-   // Call C routine to commit the transient datatype 
+   // Call C routine to commit the transient datatype
    herr_t ret_value = H5Tcommit( loc_id, name, id );
    if( ret_value < 0 )
    {
-      throw DataTypeIException("DataType::commit", "H5Tcommit failed");
+      throw DataTypeIException(inMemFunc("commit"), "H5Tcommit failed");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::commit
 ///\brief	This is an overloaded member function, provided for convenience.
-///		It differs from the above function only in the type of the 
+///		It differs from the above function only in the type of the
 ///		argument \a name.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -195,9 +195,10 @@ void DataType::commit(CommonFG& loc, const string& name) const
 
 //--------------------------------------------------------------------------
 // Function:	DataType::committed
-///\brief	Determines whether a datatype is a named type or a 
-///		transient type. 
-///\return	true if the datatype is a named type, and false, otherwise.
+///\brief	Determines whether a datatype is a named type or a
+///		transient type.
+///\return	\c true if the datatype is a named type, and \c false, 
+///		otherwise.
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -211,17 +212,17 @@ bool DataType::committed() const
       return false;
    else
    {
-      throw DataTypeIException("DataType::committed", "H5Tcommitted return negative value");
+      throw DataTypeIException(inMemFunc("committed"), "H5Tcommitted return negative value");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::find
-///\brief	Finds a conversion function that can handle a conversion 
+///\brief	Finds a conversion function that can handle a conversion
 ///		from this datatype to the specified datatype, \a dest.
 ///\param	dest   - IN: Destination datatype
 ///\param	pcdata - IN: Pointer to type conversion data
-///\return	Pointer to a suitable conversion function 
+///\return	Pointer to a suitable conversion function
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -231,25 +232,25 @@ H5T_conv_t DataType::find( const DataType& dest, H5T_cdata_t **pcdata ) const
    H5T_conv_t func = H5Tfind( id, dest.getId(), pcdata );
    if( func == NULL )
    {
-      throw DataTypeIException("DataType::find", "H5Tfind returns a NULL function");
+      throw DataTypeIException(inMemFunc("find"), "H5Tfind returns a NULL function");
    }
    return( func );
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::convert
-///\brief	Converts data from this datatype to the specified datatypes. 
+///\brief	Converts data from this datatype to the specified datatypes.
 ///\param	dest       - IN: Destination datatype
 ///\param	nelmts     - IN: Size of array \a buf
-///\param	buf        - IN/OUT: Array containing pre- and post-conversion 
+///\param	buf        - IN/OUT: Array containing pre- and post-conversion
 ///				values
 ///\param	background - IN: Optional backgroud buffer
 ///\param	plist      - IN: Dataset transfer property list
-///\return	Pointer to a suitable conversion function 
+///\return	Pointer to a suitable conversion function
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void DataType::convert( const DataType& dest, hsize_t nelmts, void *buf, void *background, PropList& plist ) const
+void DataType::convert( const DataType& dest, size_t nelmts, void *buf, void *background, PropList& plist ) const
 {
    // Get identifiers for C API
    hid_t dest_id = dest.getId();
@@ -260,22 +261,47 @@ void DataType::convert( const DataType& dest, hsize_t nelmts, void *buf, void *b
    ret_value = H5Tconvert( id, dest_id, nelmts, buf, background, plist_id );
    if( ret_value < 0 )
    {
-      throw DataTypeIException("DataType::convert", "H5Tconvert failed");
+      throw DataTypeIException(inMemFunc("convert"), "H5Tconvert failed");
    }
 }
 
-// Sets the overflow handler to a specified function. 
+/*
+These two functions may not work properly.  They will be re-evaluated 
+and tested throughly.  BMR - Oct 29, 2005
+*/
+
+//--------------------------------------------------------------------------
+// Function:	DataType::setOverflow
+///\brief	Sets the overflow handler to a specified function.
+///\param	func       - IN: Function to be called when overflow occurs
+///\return	Pointer to a suitable conversion function
+///\exception	H5::DataTypeIException
+///\par Description
+///		The function specified by \a func will be called for all 
+///		data type conversions that result in an overflow.
+///		For more information, please see:
+/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5T.html#Datatype-SetOverflow
+// Programmer	Binh-Minh Ribler - 2004
+//--------------------------------------------------------------------------
 void DataType::setOverflow( H5T_overflow_t func ) const
 {
    // Call C routine H5Tset_overflow to set the overflow handler
    herr_t ret_value = H5Tset_overflow( func );
    if( ret_value < 0 )
    {
-      throw DataTypeIException("DataType::setOverflow", "H5Tset_overflow failed");
+      throw DataTypeIException(inMemFunc("setOverflow"), "H5Tset_overflow failed");
    }
 }
 
-// Returns a pointer to the current global overflow function. 
+//--------------------------------------------------------------------------
+// Function:	DataType::getOverflow
+///\brief	Returns a pointer to the current global overflow function.
+///\return	Pointer to an application-defined function if successful; 
+///		otherwise returns NULL; this can happen if no overflow 
+///		handling function is registered.
+///\exception	H5::DataTypeIException
+// Programmer	Binh-Minh Ribler - 2004
+//--------------------------------------------------------------------------
 H5T_overflow_t DataType::getOverflow(void) const
 {
    return( H5Tget_overflow());  // C routine
@@ -285,10 +311,11 @@ H5T_overflow_t DataType::getOverflow(void) const
 //--------------------------------------------------------------------------
 // Function:	DataType::lock
 ///\brief	Locks a datatype, making it read-only and non-destructible.
+///
 ///\exception	H5::DataTypeIException
 ///\par Descrition
-///		This is normally done by the library for predefined data 
-///		types so the application doesn't inadvertently change or 
+///		This is normally done by the library for predefined data
+///		types so the application doesn't inadvertently change or
 ///		delete a predefined type.
 ///
 ///		Once a data type is locked it can never be unlocked unless
@@ -301,13 +328,13 @@ void DataType::lock() const
    herr_t ret_value = H5Tlock( id );
    if( ret_value < 0 )
    {
-      throw DataTypeIException("DataType::lock", "H5Tlock failed");
+      throw DataTypeIException(inMemFunc("lock"), "H5Tlock failed");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::getClass
-///\brief	Returns the datatype class identifier. 
+///\brief	Returns the datatype class identifier.
 ///\return	Datatype class identifier
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
@@ -319,7 +346,7 @@ H5T_class_t DataType::getClass() const
    // Return datatype class identifier if successful
    if( type_class == H5T_NO_CLASS )
    {
-      throw DataTypeIException("DataType::getClass", 
+      throw DataTypeIException(inMemFunc("getClass"),
 		"H5Tget_class returns H5T_NO_CLASS");
    }
    return( type_class );
@@ -327,7 +354,7 @@ H5T_class_t DataType::getClass() const
 
 //--------------------------------------------------------------------------
 // Function:	DataType::getSize
-///\brief	Returns the size of a datatype. 
+///\brief	Returns the size of a datatype.
 ///\return	Datatype size in bytes
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
@@ -338,7 +365,7 @@ size_t DataType::getSize() const
    size_t type_size = H5Tget_size( id );
    if( type_size <= 0 ) // valid data types are never zero size
    {
-      throw DataTypeIException("DataType::getSize", 
+      throw DataTypeIException(inMemFunc("getSize"),
 		"H5Tget_size returns invalid datatype size");
    }
    return( type_size );
@@ -346,7 +373,7 @@ size_t DataType::getSize() const
 
 //--------------------------------------------------------------------------
 // Function:	DataType::getSuper
-///\brief	Returns the base datatype from which a datatype is derived. 
+///\brief	Returns the base datatype from which a datatype is derived.
 ///\return	DataType object
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
@@ -354,7 +381,7 @@ size_t DataType::getSize() const
 DataType DataType::getSuper() const
 {
    // Call C routine to get the base datatype from which the specified
-   // datatype is derived. 
+   // datatype is derived.
    hid_t base_type_id = H5Tget_super( id );
 
    // If H5Tget_super returns a valid datatype id, create and return
@@ -366,20 +393,20 @@ DataType DataType::getSuper() const
    }
    else
    {
-      throw DataTypeIException("DataType::getSuper", "H5Tget_super failed");
+      throw DataTypeIException(inMemFunc("getSuper"), "H5Tget_super failed");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::registerFunc
-///\brief	Registers the specified conversion function. 
+///\brief	Registers the specified conversion function.
 ///\param	pers - IN: Conversion option
 ///			\li \c H5T_PERS_HARD for hard conversion functions
-///			\li \c H5T_PERS_SOFT for soft conversion functions. 
-///\param	name - IN: Name displayed in diagnostic output. 
+///			\li \c H5T_PERS_SOFT for soft conversion functions.
+///\param	name - IN: Name displayed in diagnostic output.
 ///\param	dest - IN: Destination datatype.
-///\param	func - IN: Function to convert between source and 
-///		destination datatypes. 
+///\param	func - IN: Function to convert between source and
+///		destination datatypes.
 ///\exception	H5::DataTypeIException
 ///\par Description
 ///		For more information, please see:
@@ -394,14 +421,14 @@ void DataType::registerFunc( H5T_pers_t pers, const char* name, const DataType&
    herr_t ret_value = H5Tregister( pers, name, id, dest_id, func );
    if( ret_value < 0 )
    {
-      throw DataTypeIException("DataType::registerFunc", "H5Tregister failed");
+      throw DataTypeIException(inMemFunc("registerFunc"), "H5Tregister failed");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::registerFunc
 ///\brief	This is an overloaded member function, provided for convenience.
-///		It differs from the above function only in the type of the 
+///		It differs from the above function only in the type of the
 ///		argument \a name.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -412,14 +439,14 @@ void DataType::registerFunc( H5T_pers_t pers, const string& name, const DataType
 
 //--------------------------------------------------------------------------
 // Function:	DataType::unregister
-///\brief	Removes a conversion function from all conversion paths. 
+///\brief	Removes a conversion function from all conversion paths.
 ///\param	pers - IN: Conversion option
 ///			\li \c H5T_PERS_HARD for hard conversion functions
-///			\li \c H5T_PERS_SOFT for soft conversion functions. 
-///\param	name - IN: Name displayed in diagnostic output. 
+///			\li \c H5T_PERS_SOFT for soft conversion functions.
+///\param	name - IN: Name displayed in diagnostic output.
 ///\param	dest - IN: Destination datatype.
-///\param	func - IN: Function to convert between source and 
-///		destination datatypes. 
+///\param	func - IN: Function to convert between source and
+///		destination datatypes.
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -427,18 +454,18 @@ void DataType::unregister( H5T_pers_t pers, const char* name, const DataType& de
 {
    hid_t dest_id = dest.getId();  // get id of the dest datatype for C API
 
-   // Call C routine H5Tunregister to remove the conversion function 
+   // Call C routine H5Tunregister to remove the conversion function
    herr_t ret_value = H5Tunregister( pers, name, id, dest_id, func );
    if( ret_value < 0 )
    {
-      throw DataTypeIException("DataType::unregister", "H5Tunregister failed");
+      throw DataTypeIException(inMemFunc("unregister"), "H5Tunregister failed");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::unregister
 ///\brief	This is an overloaded member function, provided for convenience.
-///		It differs from the above function only in the type of the 
+///		It differs from the above function only in the type of the
 ///		argument \a name.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -449,26 +476,26 @@ void DataType::unregister( H5T_pers_t pers, const string& name, const DataType&
 
 //--------------------------------------------------------------------------
 // Function:	DataType::setTag
-///\brief	Tags an opaque datatype. 
-///\param	tag - IN: Descriptive ASCII string with which the opaque 
-///		datatype is to be tagged. 
+///\brief	Tags an opaque datatype.
+///\param	tag - IN: Descriptive ASCII string with which the opaque
+///		datatype is to be tagged.
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void DataType::setTag( const char* tag ) const
 {
-   // Call C routine H5Tset_tag to tag an opaque datatype. 
+   // Call C routine H5Tset_tag to tag an opaque datatype.
    herr_t ret_value = H5Tset_tag( id, tag );
    if( ret_value < 0 )
    {
-      throw DataTypeIException("DataType::setTag", "H5Tset_tag failed");
+      throw DataTypeIException(inMemFunc("setTag"), "H5Tset_tag failed");
    }
 }
 
 //--------------------------------------------------------------------------
 // Function:	DataType::setTag
 ///\brief	This is an overloaded member function, provided for convenience.
-///		It differs from the above function only in the type of the 
+///		It differs from the above function only in the type of the
 ///		argument \a name.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -479,7 +506,7 @@ void DataType::setTag( const string& tag ) const
 
 //--------------------------------------------------------------------------
 // Function:	DataType::getTag
-///\brief	Gets the tag associated with an opaque datatype. 
+///\brief	Gets the tag associated with an opaque datatype.
 ///\return	Tag associated with the opaque datatype
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - 2000
@@ -493,12 +520,12 @@ string DataType::getTag() const
    if( tag_Cstr != NULL )
    {
       string tag = string(tag_Cstr); // convert C string to string object
-	HDfree(tag_Cstr); // free the C string 
-      return (tag); // return the tag 
+	HDfree(tag_Cstr); // free the C string
+      return (tag); // return the tag
    }
    else
    {
-      throw DataTypeIException("DataType::getTag", 
+      throw DataTypeIException(inMemFunc("getTag"),
 		"H5Tget_tag returns NULL for tag");
    }
 }
@@ -507,7 +534,7 @@ string DataType::getTag() const
 // Function:	DataType::detectClass
 ///\brief	Checks whether a datatype contains (or is) a certain type of
 ///		datatype.
-///\return	true if this datatype contains or is the specified type, 
+///\return	true if this datatype contains or is the specified type,
 ///		and false, otherwise.
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - May, 2004
@@ -521,7 +548,7 @@ bool DataType::detectClass(H5T_class_t cls) const
       return false;
    else
    {
-      throw DataTypeIException("DataType::detectClass", 
+      throw DataTypeIException(inMemFunc("detectClass"),
 		"H5Tdetect_class returns negative value");
    }
 }
@@ -529,7 +556,7 @@ bool DataType::detectClass(H5T_class_t cls) const
 //--------------------------------------------------------------------------
 // Function:	DataType::isVariableStr
 ///\brief	Check whether this datatype is a variable-length string.
-///\return	true if this datatype is a variable-length string, and 
+///\return	true if this datatype is a variable-length string, and
 ///		false, otherwise.
 ///\exception	H5::DataTypeIException
 // Programmer	Binh-Minh Ribler - May, 2004
@@ -543,7 +570,7 @@ bool DataType::isVariableStr() const
       return false;
    else
    {
-      throw DataTypeIException("DataType::isVariableStr",
+      throw DataTypeIException(inMemFunc("isVariableStr"),
                 "H5Tis_variable_str returns negative value");
    }
 }
@@ -555,12 +582,17 @@ bool DataType::isVariableStr() const
 ///\param	dataspace - IN: Dataspace with selection
 ///\param	ref_type - IN: Type of reference; default to \c H5R_DATASET_REGION
 ///\return	A reference
-///\exception	H5::ReferenceIException
+///\exception	H5::IdComponentException
 // Programmer	Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
 void* DataType::Reference(const char* name, DataSpace& dataspace, H5R_type_t ref_type) const
 {
-   return(p_reference(name, dataspace.getId(), ref_type));
+   try {
+      return(p_reference(name, dataspace.getId(), ref_type));
+   }
+   catch (IdComponentException E) {
+      throw DataTypeIException(inMemFunc("Reference"), E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -570,16 +602,34 @@ void* DataType::Reference(const char* name, DataSpace& dataspace, H5R_type_t ref
 ///		a reference to an HDF5 object, not to a dataset region.
 ///\param	name - IN: Name of the object to be referenced
 ///\return	A reference
-///\exception	H5::ReferenceIException
+///\exception	H5::IdComponentException
 ///\par Description
-//		This function passes H5R_OBJECT and -1 to the protected 
+//		This function passes H5R_OBJECT and -1 to the protected
 //		function for it to pass to the C API H5Rcreate
 //		to create a reference to the named object.
 // Programmer	Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
 void* DataType::Reference(const char* name) const
 {
-   return(p_reference(name, -1, H5R_OBJECT));
+   try {
+      return(p_reference(name, -1, H5R_OBJECT));
+   }
+   catch (IdComponentException E) {
+      throw DataTypeIException(inMemFunc("Reference"), E.getDetailMsg());
+   }
+}
+
+//--------------------------------------------------------------------------
+// Function:	DataType::Reference
+///\brief	This is an overloaded function, provided for your convenience.
+///		It differs from the above function in that it takes an
+///		\c std::string for the object's name.
+///\param	name - IN: Name of the object to be referenced - \c std::string
+// Programmer	Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void* DataType::Reference(const string& name) const
+{
+   return(Reference(name.c_str()));
 }
 
 //--------------------------------------------------------------------------
@@ -588,16 +638,21 @@ void* DataType::Reference(const char* name) const
 ///\param		ref      - IN: Reference to query
 ///\param		ref_type - IN: Type of reference to query
 ///\return	Object type, which can be one of the following:
-///			\li \c H5G_LINK Object is a symbolic link.  
-///			\li \c H5G_GROUP Object is a group.  
-///			\li \c H5G_DATASET   Object is a dataset.  
-///			\li \c H5G_TYPE Object is a named datatype 
-///\exception	H5::ReferenceIException
+///			\li \c H5G_LINK Object is a symbolic link.
+///			\li \c H5G_GROUP Object is a group.
+///			\li \c H5G_DATASET   Object is a dataset.
+///			\li \c H5G_TYPE Object is a named datatype
+///\exception	H5::IdComponentException
 // Programmer	Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
 H5G_obj_t DataType::getObjType(void *ref, H5R_type_t ref_type) const
 {
-   return(p_get_obj_type(ref, ref_type));
+   try {
+      return(p_get_obj_type(ref, ref_type));
+   }
+   catch (IdComponentException E) {
+      throw DataTypeIException(inMemFunc("getObjType"), E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -606,59 +661,64 @@ H5G_obj_t DataType::getObjType(void *ref, H5R_type_t ref_type) const
 ///\param	ref      - IN: Reference to get region of
 ///\param	ref_type - IN: Type of reference to get region of - default
 ///\return	DataSpace instance
-///\exception	H5::ReferenceIException
+///\exception	H5::IdComponentException
 // Programmer	Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
 DataSpace DataType::getRegion(void *ref, H5R_type_t ref_type) const
 {
-   DataSpace dataspace(p_get_region(ref, ref_type));
-   return(dataspace);
+   try {
+      DataSpace dataspace(p_get_region(ref, ref_type));
+      return(dataspace);
+   }
+   catch (IdComponentException E) {
+      throw DataTypeIException(inMemFunc("getRegion"), E.getDetailMsg());
+   }
 }
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
 //--------------------------------------------------------------------------
-// Function:    DataType::p_close (private)
-// Purpose:     Closes the datatype if it is not a predefined type.
-// Exception    H5::DataTypeIException
-// Description
-//              This function will be obsolete because its functionality
-//              is recently handled by the C library layer. - May, 2004
-// Programmer   Binh-Minh Ribler - 2000
+// Function:	DataType::close
+///\brief	Closes the datatype if it is not a predefined type.
+///
+///\exception	H5::DataTypeIException
+// Programmer	Binh-Minh Ribler - Mar 9, 2005
 //--------------------------------------------------------------------------
-void DataType::p_close() const
+void DataType::close()
 {
    // If this datatype is not a predefined type, call H5Tclose on it.
    if( is_predtype == false )
    {
-      herr_t ret_value = H5Tclose( id );
+      herr_t ret_value = H5Tclose(id);
       if( ret_value < 0 )
       {
-         throw DataTypeIException(0, "H5Tclose failed");
+         throw DataTypeIException(inMemFunc("close"), "H5Tclose failed");
       }
+      // reset the id because the datatype that it represents is now closed
+      id = 0;
    }
+   else // cannot close a predefined type
+      throw DataTypeIException(inMemFunc("close"), "Cannot close a predefined type");
 }
-#endif // DOXYGEN_SHOULD_SKIP_THIS
 
 //--------------------------------------------------------------------------
 // Function:	DataType destructor
 ///\brief	Properly terminates access to this datatype.
 // Programmer	Binh-Minh Ribler - 2000
 // Modification
-//              Replaced resetIdComponent with decRefCount to use new ID
-//              reference counting mechanisms by QAK, Feb 20, 2005
+//		Replaced resetIdComponent with decRefCount to use C library
+//		ID reference counting mechanism - BMR, Feb 20, 2005
 //--------------------------------------------------------------------------
 DataType::~DataType()
-{  
+{
    // The datatype id will be closed properly
    if( is_predtype == false ) {
         try {
             decRefCount();
         }
         catch (Exception close_error) {
-            cerr << "DataType::~DataType - " << close_error.getDetailMsg() << endl;
+            cerr << inMemFunc("~DataType - ") << close_error.getDetailMsg() << endl;
         }
     }
-}  
+}
 
 #ifndef H5_NO_NAMESPACE
 } // end namespace
