@@ -1,16 +1,16 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-  * Copyright by the Board of Trustees of the University of Illinois.         *
-  * All rights reserved.                                                      *
-  *                                                                           *
-  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
-  * terms governing use, modification, and redistribution, is contained in    *
-  * the files COPYING and Copyright.html.  COPYING can be found at the root   *
-  * of the source code distribution tree; Copyright.html can be found at the  *
-  * root level of an installed copy of the electronic HDF5 document set and   *
-  * is linked from the top-level documents page.  It can also be found at     *
-  * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
-  * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
-  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at the  *
+ * root level of an installed copy of the electronic HDF5 document set and   *
+ * is linked from the top-level documents page.  It can also be found at     *
+ * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
+ * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include <string>
 
@@ -27,7 +27,7 @@ namespace H5 {
 //--------------------------------------------------------------------------
 ///\brief	Constant for default dataset memory and transfer property list.
 //--------------------------------------------------------------------------
-const DSetMemXferPropList DSetMemXferPropList::DEFAULT( H5P_DEFAULT );
+const DSetMemXferPropList DSetMemXferPropList::DEFAULT;
 
 //--------------------------------------------------------------------------
 // Function     Default constructor
@@ -51,7 +51,7 @@ DSetMemXferPropList::DSetMemXferPropList(const DSetMemXferPropList& original) :
 // Function     DSetMemXferPropList overloaded constructor
 ///\brief	Creates a DSetMemXferPropList object using the id of an
 ///		existing DSetMemXferPropList.
-///\param       plist_id - IN: Id of an existing dataset memory and transfer 
+///\param       plist_id - IN: Id of an existing dataset memory and transfer
 ///				property list
 // Programmer:  Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -179,15 +179,15 @@ bool DSetMemXferPropList::getPreserve() const
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::setHyperCache
 ///\brief	Indicates whether to cache hyperslab blocks during I/O
-///\param	cache - IN: Flag indicating whether caching is to be set 
+///\param	cache - IN: Flag indicating whether caching is to be set
 ///			    to on (1) or off (0)
 ///\param	limit - IN: Maximum size of the hyperslab block to cache or
 ///			    0 (zero) for no limit
 ///\exception	H5::PropListIException
-///\note	This function is deprecated in HDF5 Release 1.6 and will 
-///		eventually be removed from the HDF5 distribution. It is 
-///		provided in this release only to enable backward compatibility 
-///		with HDF5 Releases 1.4.x and is enabled only if the HDF5 
+///\note	This function is deprecated in HDF5 Release 1.6 and will
+///		eventually be removed from the HDF5 distribution. It is
+///		provided in this release only to enable backward compatibility
+///		with HDF5 Releases 1.4.x and is enabled only if the HDF5
 ///		library is configured with the flag H5_WANT_H5_V1_4_COMPAT.
 // Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -203,17 +203,17 @@ void DSetMemXferPropList::setHyperCache( bool cache, unsigned limit ) const
 
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::getHyperCache
-///\brief	Returns information regarding the caching of hyperslab 
+///\brief	Returns information regarding the caching of hyperslab
 ///		blocks during I/O.
-///\param	cache - OUT: Flag indicating whether caching is set 
+///\param	cache - OUT: Flag indicating whether caching is set
 ///			    to on (1) or off (0)
 ///\param	limit - OUT: Maximum size of the hyperslab block to cache or
 ///			    0 (zero) for no limit
 ///\exception	H5::PropListIException
-///\note	This function is deprecated in HDF5 Release 1.6 and will 
-///		eventually be removed from the HDF5 distribution. It is 
-///		provided in this release only to enable backward compatibility 
-///		with HDF5 Releases 1.4.x and is enabled only if the HDF5 
+///\note	This function is deprecated in HDF5 Release 1.6 and will
+///		eventually be removed from the HDF5 distribution. It is
+///		provided in this release only to enable backward compatibility
+///		with HDF5 Releases 1.4.x and is enabled only if the HDF5
 ///		library is configured with the flag H5_WANT_H5_V1_4_COMPAT.
 // Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -283,7 +283,7 @@ void DSetMemXferPropList::getBtreeRatios( double& left, double& middle, double&
 //--------------------------------------------------------------------------
 void DSetMemXferPropList::setVlenMemManager( H5MM_allocate_t alloc_func, void* alloc_info, H5MM_free_t free_func, void* free_info ) const
 {
-   herr_t ret_value = H5Pset_vlen_mem_manager( id, alloc_func, alloc_info, 
+   herr_t ret_value = H5Pset_vlen_mem_manager( id, alloc_func, alloc_info,
 						free_func, free_info );
    if( ret_value < 0 )
    {
@@ -294,8 +294,9 @@ void DSetMemXferPropList::setVlenMemManager( H5MM_allocate_t alloc_func, void* a
 
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::setVlenMemManager
-///\brief	Sets the memory manager for variable-length datatype 
+///\brief	Sets the memory manager for variable-length datatype
 ///		allocation - system \c malloc and \c free will be used.
+///
 ///\exception	H5::PropListIException
 // Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -306,7 +307,7 @@ void DSetMemXferPropList::setVlenMemManager() const
 
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::getVlenMemManager
-///\brief	Gets the memory manager for variable-length datatype allocation 
+///\brief	Gets the memory manager for variable-length datatype allocation
 ///\param       alloc_func - OUT: User's allocate routine
 ///\param	alloc_info - OUT: User's allocation parameters
 ///\param	free_func  - OUT: User's free routine
@@ -330,7 +331,7 @@ void DSetMemXferPropList::getVlenMemManager( H5MM_allocate_t& alloc_func, void**
 ///\param       memb_dxpl - OUT: Array of data access property lists
 ///\exception	H5::PropListIException
 ///\par Description
-///		This function can only be used after the member map has 
+///		This function can only be used after the member map has
 ///		been set with FileAccPropList::setMulti (not done - BMR.)
 // Programmer:	Binh-Minh Ribler - July, 2004
 //--------------------------------------------------------------------------
@@ -364,7 +365,7 @@ void DSetMemXferPropList::getMulti(hid_t *memb_dxpl)
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::setSmallDataBlockSize
 ///\brief	Sets the size of a contiguous block reserved for small data.
-///\param       size - IN: Maximum size, in bytes, of the small data block. 
+///\param       size - IN: Maximum size, in bytes, of the small data block.
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For detail, please refer to the C layer Reference Manual at:
@@ -403,6 +404,7 @@ hsize_t DSetMemXferPropList::getSmallDataBlockSize()
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::setHyperVectorSize
 ///\brief	Sets number of I/O vectors to be read/written in hyperslab I/O.
+///
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For information, please refer to the C layer Reference
@@ -422,7 +424,7 @@ void DSetMemXferPropList::setHyperVectorSize(size_t vector_size)
 
 //--------------------------------------------------------------------------
 // Function:	DSetMemXferPropList::getSmallDataBlockSize
-///\brief	Returns the number of I/O vectors to be read/written in 
+///\brief	Returns the number of I/O vectors to be read/written in
 ///		hyperslab I/O.
 ///\return	Number of I/O vectors
 ///\exception	H5::PropListIException
@@ -448,14 +450,14 @@ size_t DSetMemXferPropList::getHyperVectorSize()
 ///				disabled
 ///\exception	H5::PropListIException
 ///\par Description
-///		The error detection algorithm used is the algorithm previously 
-///		specified in the corresponding dataset creation property 
-///		list.  This function does not affect the use of error 
+///		The error detection algorithm used is the algorithm previously
+///		specified in the corresponding dataset creation property
+///		list.  This function does not affect the use of error
 ///		detection in the writing process.
 ///\par
 ///		Valid values are as follows:
-///		\li \c H5Z_ENABLE_EDC   (default) 
-///		\li \c H5Z_DISABLE_EDC  
+///		\li \c H5Z_ENABLE_EDC   (default)
+///		\li \c H5Z_DISABLE_EDC
 // Programmer:	Binh-Minh Ribler - July, 2004
 //--------------------------------------------------------------------------
 void DSetMemXferPropList::setEDCCheck(H5Z_EDC_t check)
