@@ -1,16 +1,16 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-  * Copyright by the Board of Trustees of the University of Illinois.         *
-  * All rights reserved.                                                      *
-  *                                                                           *
-  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
-  * terms governing use, modification, and redistribution, is contained in    *
-  * the files COPYING and Copyright.html.  COPYING can be found at the root   *
-  * of the source code distribution tree; Copyright.html can be found at the  *
-  * root level of an installed copy of the electronic HDF5 document set and   *
-  * is linked from the top-level documents page.  It can also be found at     *
-  * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
-  * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
-  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at the  *
+ * root level of an installed copy of the electronic HDF5 document set and   *
+ * is linked from the top-level documents page.  It can also be found at     *
+ * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
+ * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*****************************************************************************
    FILE
@@ -30,14 +30,15 @@
 #include <iostream>
 #endif
 
-#include "H5Cpp.h"
-#include "testhdf5.h"
-#include "h5cpputil.h"
+#include "testhdf5.h"	// C test header file
+#include "H5Cpp.h"	// C++ API header file
 
 #ifndef H5_NO_NAMESPACE
 using namespace H5;
 #endif
 
+#include "h5cpputil.h"	// C++ utilility header file
+
 const hsize_t F1_USERBLOCK_SIZE = (hsize_t)0;
 const size_t F1_OFFSET_SIZE = sizeof(haddr_t);
 const size_t F1_LENGTH_SIZE = sizeof(hsize_t);
@@ -98,7 +99,7 @@ const string    FILE4("tfile4.h5");
  *
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_file_create(void)
 {
     // Output message about test being performed
@@ -114,8 +115,8 @@ test_file_create(void)
     // Setting this to NULL for cleaning up in failure situations
     H5File* file1 = NULL;
     try {
-        // Create file FILE1
-        file1 = new H5File (FILE1, H5F_ACC_EXCL);
+	// Create file FILE1
+	file1 = new H5File (FILE1, H5F_ACC_EXCL);
 
 	// try to create the same file with H5F_ACC_TRUNC. This should fail
 	// because file1 is the same file and is currently open.
@@ -128,13 +129,13 @@ test_file_create(void)
 	catch( FileIException E ) // catch truncating existing file
 	{} // do nothing, FAIL expected
 
-	// Close file1 
+	// Close file1
 	delete file1;
 	file1 = NULL;
 
-	// Try again with H5F_ACC_EXCL. This should fail because the file 
+	// Try again with H5F_ACC_EXCL. This should fail because the file
 	// already exists from the previous steps.
-	try { 
+	try {
 	    H5File file2(FILE1, H5F_ACC_EXCL);  // should throw E
 
 	    // Should FAIL but didn't, so throw an invalid action exception
@@ -146,7 +147,7 @@ test_file_create(void)
     	// Test create with H5F_ACC_TRUNC. This will truncate the existing file.
 	file1 = new H5File (FILE1, H5F_ACC_TRUNC);
 
-     	// Try to truncate first file again. This should fail because file1 
+	// Try to truncate first file again. This should fail because file1
 	// is the same file and is currently open.
     	try {
 	    H5File file2 (FILE1, H5F_ACC_TRUNC);   // should throw E
@@ -174,15 +175,15 @@ test_file_create(void)
 	hsize_t ublock = tmpl1.getUserblock();
 	verify_val((long)ublock, (long)F1_USERBLOCK_SIZE, "FileCreatPropList::getUserblock", __LINE__, __FILE__);
 
-    	size_t  parm1, parm2;		/*file-creation parameters	*/
+    	size_t  parm1, parm2;	// file-creation parameters
 	tmpl1.getSizes( parm1, parm2);
 	verify_val(parm1, F1_OFFSET_SIZE, "FileCreatPropList::getSizes", __LINE__, __FILE__);
 	verify_val(parm2, F1_LENGTH_SIZE, "FileCreatPropList::getSizes", __LINE__, __FILE__);
 
 #ifdef H5_WANT_H5_V1_4_COMPAT
-    	int iparm1, iparm2;	/*file-creation parameters	*/
+    	int iparm1, iparm2;	// file-creation parameters
 #else /* H5_WANT_H5_V1_4_COMPAT */
-    	unsigned  iparm1, iparm2;	/*file-creation parameters	*/
+    	unsigned  iparm1, iparm2;	// file-creation parameters
 #endif /* H5_WANT_H5_V1_4_COMPAT */
     	tmpl1.getSymk( iparm1, iparm2);
 	verify_val(iparm1, F1_SYM_INTERN_K, "FileCreatPropList::getSymk", __LINE__, __FILE__);
@@ -284,12 +285,14 @@ test_file_create(void)
 	// Release file-creation template
 	delete tmpl1;
     }
-    catch( PropListIException E ) {
+    // catch all exceptions
+    catch (Exception E)
+    {
 	issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
-        if (tmpl1 != NULL)  // clean up
-            delete tmpl1;
+	if (tmpl1 != NULL)  // clean up
+	    delete tmpl1;
     }
-} /* test_file_create() */
+}   // test_file_create()
 
 
 /*-------------------------------------------------------------------------
@@ -303,7 +306,7 @@ test_file_create(void)
  *              January, 2001
  *
  * Modifications:
- *      January, 2005: C tests' macro VERIFY casts values to 'long' for all
+ *	January, 2005: C tests' macro VERIFY casts values to 'long' for all
  *		       cases.  Since there are no operator<< for 'long long'
  *		       or int64 in VS C++ ostream, I casted the hsize_t values
  *		       passed to verify_val to 'long' as well.  If problems
@@ -312,7 +315,7 @@ test_file_create(void)
  *
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_file_open(void)
 {
     // Output message about test being performed
@@ -337,9 +340,9 @@ test_file_open(void)
 	verify_val(parm2, F2_LENGTH_SIZE, "FileCreatPropList::getSizes", __LINE__, __FILE__);
 
 #ifdef H5_WANT_H5_V1_4_COMPAT
-	int  iparm1, iparm2;       // file-creation parameters     
+	int  iparm1, iparm2;       // file-creation parameters
 #else /* H5_WANT_H5_V1_4_COMPAT */
-	unsigned  iparm1, iparm2;       // file-creation parameters     
+	unsigned  iparm1, iparm2;       // file-creation parameters
 #endif /* H5_WANT_H5_V1_4_COMPAT */
 	tmpl1.getSymk( iparm1, iparm2);
 	verify_val(iparm1, F2_SYM_INTERN_K, "FileCreatPropList::getSymk", __LINE__, __FILE__);
@@ -349,13 +352,13 @@ test_file_open(void)
     catch( Exception E ) {
         issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
-} /* test_file_open() */
+}   // test_file_open()
 
 
 /*-------------------------------------------------------------------------
  * Function:    test_file_size
  *
- * Purpose:     Test file size.  
+ * Purpose:     Test file size.
  *
  * Return:      None
  *
@@ -366,7 +369,7 @@ test_file_open(void)
  *
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_file_size(void)
 {
     // Output message about test being performed
@@ -383,7 +386,7 @@ test_file_size(void)
     	// Set to sec2 driver.  Do we want to test other file drivers?
         // They're not tested in C++.
         // File drivers seem not implemented.
-	//fapl.setSec2();
+	// fapl.setSec2();
 
         // Create a file
 	H5File file4( FILE4, H5F_ACC_TRUNC, FileCreatPropList::DEFAULT, fapl);
@@ -402,14 +405,14 @@ test_file_size(void)
 
     // use C test utility routine to close property list.
     H5Pclose(fapl_id);
-    
-} /* test_file_size() */
+
+}   // test_file_size()
 
 
 /*-------------------------------------------------------------------------
  * Function:    test_file_name
  *
- * Purpose:     Test getting file's name.  
+ * Purpose:     Test getting file's name.
  *
  * Return:      None
  *
@@ -434,7 +437,7 @@ typedef struct s1_t {
     float        b;
 } s1_t;
 
-static void 
+static void
 test_file_name()
 {
     // Output message about test being performed
@@ -456,7 +459,7 @@ test_file_name()
 	file_name = group.getFileName();
 	verify_val(file_name, FILE4, "Group::getFileName", __LINE__, __FILE__);
 
-	// Create the data space 
+	// Create the data space
 	hsize_t dims[RANK] = {NX, NY};
 	DataSpace space(RANK, dims);
 
@@ -493,13 +496,13 @@ test_file_name()
         issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-} /* test_file_name() */
+}   // test_file_name()
 
 
 /*-------------------------------------------------------------------------
  * Function:    test_file
  *
- * Purpose:     Main program
+ * Purpose:     Main file testing routine
  *
  * Return:      None
  *
@@ -510,7 +513,7 @@ test_file_name()
  *
  *-------------------------------------------------------------------------
  */
-void 
+void
 test_file(void)
 {
     // Output message about test being performed
@@ -520,7 +523,7 @@ test_file(void)
     test_file_open();	// Test file opening
     test_file_size();	// Test file size
     test_file_name();	// Test getting file's name
-} /* test_file() */
+}   // test_file()
 
 
 /*-------------------------------------------------------------------------
@@ -543,4 +546,4 @@ cleanup_file(void)
     remove(FILE2.c_str());
     remove(FILE3.c_str());
     remove(FILE4.c_str());
-} /* cleanup_file */
+}   // cleanup_file
