@@ -1,16 +1,16 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-  * Copyright by the Board of Trustees of the University of Illinois.         *
-  * All rights reserved.                                                      *
-  *                                                                           *
-  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
-  * terms governing use, modification, and redistribution, is contained in    *
-  * the files COPYING and Copyright.html.  COPYING can be found at the root   *
-  * of the source code distribution tree; Copyright.html can be found at the  *
-  * root level of an installed copy of the electronic HDF5 document set and   *
-  * is linked from the top-level documents page.  It can also be found at     *
-  * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
-  * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
-  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at the  *
+ * root level of an installed copy of the electronic HDF5 document set and   *
+ * is linked from the top-level documents page.  It can also be found at     *
+ * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
+ * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*****************************************************************************
    FILE
@@ -27,13 +27,14 @@
 #include <iostream>
 #endif
 
-#include "testhdf5.h"
-#include "H5Cpp.h"
-#include "h5cpputil.h"
+#include "testhdf5.h"	// C test header file
+#include "H5Cpp.h"	// C++ API header file
 
 #ifndef H5_NO_NAMESPACE
 using namespace H5;
-#endif  /* !H5_NO_NAMESPACE */
+#endif
+
+#include "h5cpputil.h"	// C++ utilility header file
 
 const string    TESTFILE("th5s.h5");
 const string    DATAFILE("th5s1.h5");
@@ -81,7 +82,7 @@ struct space4_struct {
  } space4_data={'v',987123,(float)-3.14,'g'}; /* Test data for 4th dataspace */
 
 /*-------------------------------------------------------------------------
- *  
+ *
  * Function:	test_h5s_basic
  *
  * Purpose:	Test basic H5S (dataspace) code
@@ -100,7 +101,7 @@ struct space4_struct {
  *		       with a special routine.
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_h5s_basic(void)
 {
     hsize_t		dims1[] = {SPACE1_DIM1, SPACE1_DIM2, SPACE1_DIM3};
@@ -109,32 +110,29 @@ test_h5s_basic(void)
     hsize_t		dims3[H5S_MAX_RANK+1];
     hsize_t		tmax[4];
 
-    /* Output message about test being performed */
+    // Output message about test being performed
     MESSAGE(5, ("Testing Dataspace Manipulation\n"));
 
-    try 
+    try
     { // beginning of first try block
 
-	/* Create file - removed this since the following operations don't
-	need the file to be opened */
-
 	// Create simple dataspace sid1
 	DataSpace sid1 (SPACE1_RANK, dims1 );
 
 	// Get simple extent npoints of the dataspace sid1 and verify it
-	hssize_t	n;	 	/* Number of dataspace elements */
+	hssize_t	n;	 	// Number of dataspace elements
 	n = sid1.getSimpleExtentNpoints();
 	verify_val((long)n, (long)(SPACE1_DIM1 * SPACE1_DIM2 * SPACE1_DIM3),
 	   "DataSpace::getSimpleExtentNpoints", __LINE__, __FILE__);
 
 	// Get the logical rank of dataspace sid1 and verify it
-	int	rank;		/* Logical rank of dataspace	*/
+	int	rank;		// Logical rank of dataspace
 	rank = sid1.getSimpleExtentNdims();
 	verify_val(rank, SPACE1_RANK, "DataSpace::getSimpleExtentNdims", __LINE__, __FILE__);
 
 	// Retrieves dimension size of dataspace sid1 and verify it
-	int ndims;		/* Number of dimensions		*/
-	hsize_t	tdims[4];	/* Dimension array to test with */
+	int ndims;		// Number of dimensions
+	hsize_t	tdims[4];	// Dimension array to test with
 	ndims = sid1.getSimpleExtentDims( tdims );
 	verify_val(HDmemcmp(tdims, dims1, SPACE1_RANK * sizeof(unsigned)), 0,
 	   "DataSpace::getSimpleExtentDims", __LINE__, __FILE__);
@@ -152,7 +150,7 @@ test_h5s_basic(void)
 	rank = sid2.getSimpleExtentNdims();
 	verify_val(rank, SPACE2_RANK, "DataSpace::getSimpleExtentNdims", __LINE__, __FILE__);
 
-	// Retrieves dimension size and max size of dataspace sid2 and 
+	// Retrieves dimension size and max size of dataspace sid2 and
 	// verify them
 	ndims = sid2.getSimpleExtentDims( tdims, tmax );
 	verify_val(HDmemcmp(tdims, dims2, SPACE2_RANK * sizeof(unsigned)), 0,
@@ -162,7 +160,7 @@ test_h5s_basic(void)
 
 	// Check to be sure we can't create a simple data space that has too
 	// many dimensions.
-	try { 
+	try {
 	    DataSpace manydims_ds(H5S_MAX_RANK+1, dims3, NULL);
 
 	    // Should FAIL but didn't, so throw an invalid action exception
@@ -189,10 +187,10 @@ test_h5s_basic(void)
 	// Create file
 	H5File fid1(testfile, H5F_ACC_RDONLY);
 
-	// Try to open the dataset that has higher dimensionality than 
+	// Try to open the dataset that has higher dimensionality than
 	// what the library can handle and this operation should fail.
 	try {
-	    DataSet dset1 = fid1.openDataSet( "dset" ); 
+	    DataSet dset1 = fid1.openDataSet( "dset" );
 
 	    // Should FAIL but didn't, so throw an invalid action exception
 	    throw InvalidActionException("H5File::openDataSet", "Opening a dataset with higher dimensionality than what the library can handle");
@@ -206,7 +204,7 @@ test_h5s_basic(void)
     // Verify that incorrect dimensions don't work
 	dims1[0] = 0;
 	try {
-	    DataSpace wrongdim_ds (SPACE1_RANK, dims1); 
+	    DataSpace wrongdim_ds (SPACE1_RANK, dims1);
 
 	    // Should FAIL but didn't, so throw an invalid action exception
 	    throw InvalidActionException("DataSpace constructor", "Attempted to use incorrect dimensions");
@@ -232,14 +230,14 @@ test_h5s_basic(void)
         cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
     }
     // catch all other exceptions
-    catch (Exception E) 
+    catch (Exception E)
     {
         issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
-}				/* test_h5s_basic() */
+}   // test_h5s_basic()
 
 /*-------------------------------------------------------------------------
- *  
+ *
  * Function:	test_h5s_scalar_write
  *
  * Purpose:	Test scalar H5S (dataspace) writing code
@@ -258,11 +256,10 @@ test_h5s_basic(void)
  *		       with a special routine.
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_h5s_scalar_write(void)
 {
-
-    /* Output message about test being performed */
+    // Output message about test being performed
     MESSAGE(5, ("Testing Scalar Dataspace Writing\n"));
 
     try
@@ -270,42 +267,42 @@ test_h5s_scalar_write(void)
 	// Create file
 	H5File fid1(DATAFILE, H5F_ACC_TRUNC);
 
-	/* Create scalar dataspace */
+	// Create scalar dataspace
 	DataSpace sid1(SPACE3_RANK, NULL);
 
 	//n = H5Sget_simple_extent_npoints(sid1);
-	hssize_t	n;	 	/* Number of dataspace elements */
+	hssize_t	n;	 	// Number of dataspace elements
 	n = sid1.getSimpleExtentNpoints();
 	verify_val((long)n, 1, "DataSpace::getSimpleExtentNpoints", __LINE__, __FILE__);
 
-	int	rank;		/* Logical rank of dataspace	*/
+	int	rank;		// Logical rank of dataspace
 	rank = sid1.getSimpleExtentNdims();
 	verify_val(rank, SPACE3_RANK, "DataSpace::getSimpleExtentNdims", __LINE__, __FILE__);
 
 	// Retrieves dimension size of dataspace sid1 and verify it
-	int ndims;		/* Number of dimensions		*/
-	hsize_t	tdims[4];	/* Dimension array to test with */
+	int ndims;		// Number of dimensions
+	hsize_t	tdims[4];	// Dimension array to test with
 	ndims = sid1.getSimpleExtentDims( tdims );
 	verify_val(ndims, 0, "DataSpace::getSimpleExtentDims", __LINE__, __FILE__);
 
-	/* Verify extent type */
-	H5S_class_t ext_type;   /* Extent type */
+	// Verify extent type
+	H5S_class_t ext_type;   // Extent type
 	ext_type = sid1.getSimpleExtentType();
 	verify_val(ext_type, H5S_SCALAR, "DataSpace::getSimpleExtentType", __LINE__, __FILE__);
 
-	/* Create a dataset */
+	// Create a dataset
 	DataSet dataset = fid1.createDataSet("Dataset1", PredType::NATIVE_UINT,sid1);
 
 	dataset.write(&space3_data, PredType::NATIVE_UINT);
     } // end of try block
-    catch (Exception error)
+    catch (Exception E)
     {
-	issue_fail_msg(error.getCFuncName(), __LINE__, __FILE__);
+	issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
-}				/* test_h5s_scalar_write() */
+}   // test_h5s_scalar_write()
 
 /*-------------------------------------------------------------------------
- *  
+ *
  * Function:	test_h5s_scalar_read
  *
  * Purpose:	Test scalar H5S (dataspace) reading code
@@ -324,20 +321,20 @@ test_h5s_scalar_write(void)
  *		       with a special routine.
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_h5s_scalar_read(void)
 {
-    hsize_t		tdims[4];	/* Dimension array to test with */
+    hsize_t		tdims[4];	// Dimension array to test with
 
-    /* Output message about test being performed */
+    // Output message about test being performed
     MESSAGE(5, ("Testing Scalar Dataspace Reading\n"));
 
     try
     {
-	/* Create file */
+	// Create file
 	H5File fid1(DATAFILE, H5F_ACC_RDWR);
 
-	/* Create a dataset */
+	// Create a dataset
 	DataSet dataset = fid1.openDataSet("Dataset1");
 
 	DataSpace sid1 = dataset.getSpace();
@@ -353,23 +350,23 @@ test_h5s_scalar_read(void)
 	ndims = sid1.getSimpleExtentDims(tdims);
 	verify_val(ndims, 0, "DataSpace::getSimpleExtentDims", __LINE__, __FILE__);
 
-	unsigned      	rdata;      	/* Scalar data read in 		*/
+	unsigned      	rdata;      	// Scalar data read in
 	dataset.read(&rdata, PredType::NATIVE_UINT);
 	verify_val(rdata, space3_data, "DataSet::read", __LINE__, __FILE__);
     }   // end of try block
-    catch (Exception error)
+    catch (Exception E)
     {
 	// all the exceptions caused by negative returned values by C APIs
-	issue_fail_msg(error.getCFuncName(), __LINE__, __FILE__);
+	issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
-    
-}				/* test_h5s_scalar_read() */
+
+}   // test_h5s_scalar_read()
 
 /*-------------------------------------------------------------------------
- *  
+ *
  * Function:	test_h5s_compound_scalar_write
  *
- * Purpose:	Test scalar H5S (dataspace) writing for compound 
+ * Purpose:	Test scalar H5S (dataspace) writing for compound
  *		datatypes
  *
  * Return:	none
@@ -386,19 +383,18 @@ test_h5s_scalar_read(void)
  *		       with a special routine.
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_h5s_compound_scalar_write(void)
 {
-
-    /* Output message about test being performed */
+    // Output message about test being performed
     MESSAGE(5, ("Testing Compound Dataspace Writing\n"));
 
     try
     {
-	/* Create file */
+	// Create file
 	H5File fid1(DATAFILE, H5F_ACC_TRUNC);
 
-	/* Create the compound datatype.  */
+	// Create the compound datatype.
 	CompType tid1(sizeof(struct space4_struct));
 	space4_field1_off=HOFFSET(struct space4_struct, c1);
 	tid1.insertMember(SPACE4_FIELDNAME1, space4_field1_off,
@@ -413,7 +409,7 @@ test_h5s_compound_scalar_write(void)
 	tid1.insertMember(SPACE4_FIELDNAME4, space4_field4_off,
 		    PredType::NATIVE_SCHAR);
 
-	/* Create scalar dataspace */
+	// Create scalar dataspace
 	DataSpace sid1(SPACE3_RANK, NULL);
 
 	// Get the number of dataspace elements
@@ -424,28 +420,27 @@ test_h5s_compound_scalar_write(void)
 	int ndims = sid1.getSimpleExtentNdims();
 	verify_val(ndims, SPACE3_RANK, "DataSpace::getSimpleExtentNdims", __LINE__, __FILE__);
 
-	hsize_t		tdims[4];	/* Dimension array to test with */
+	hsize_t		tdims[4];	// Dimension array to test with
 	ndims = sid1.getSimpleExtentDims(tdims);
 	verify_val(ndims, 0, "DataSpace::getSimpleExtentDims", __LINE__, __FILE__);
 
-	/* Create a dataset */
+	// Create a dataset
 	DataSet dataset = fid1.createDataSet("Dataset1", tid1, sid1);
 
 	dataset.write(&space4_data, tid1);
     }	// end of try block
-    catch (Exception error)
+    catch (Exception E)
     {
 	// all the exceptions caused by negative returned values by C APIs
-	issue_fail_msg(error.getCFuncName(), __LINE__, __FILE__);
+	issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
-
-}				/* test_h5s_compound_scalar_write() */
+}   // test_h5s_compound_scalar_write()
 
 /*-------------------------------------------------------------------------
- *  
+ *
  * Function:	test_h5s_compound_scalar_read
  *
- * Purpose:	Test scalar H5S (dataspace) reading for compound 
+ * Purpose:	Test scalar H5S (dataspace) reading for compound
  *		datatypes
  *
  * Return:	none
@@ -462,19 +457,19 @@ test_h5s_compound_scalar_write(void)
  *		       with a special routine.
  *-------------------------------------------------------------------------
  */
-static void 
+static void
 test_h5s_compound_scalar_read(void)
 {
-    hsize_t		tdims[4];	/* Dimension array to test with */
+    hsize_t		tdims[4];	// Dimension array to test with
 
-    /* Output message about test being performed */
+    // Output message about test being performed
     MESSAGE(5, ("Testing Compound Dataspace Reading\n"));
     try
     {
-	/* Create file */
+	// Create file
 	H5File fid1(DATAFILE, H5F_ACC_RDWR);
 
-	/* Create a dataset */
+	// Create a dataset
 	DataSet dataset = fid1.openDataSet("Dataset1");
 
 	DataSpace sid1 = dataset.getSpace();
@@ -492,14 +487,14 @@ test_h5s_compound_scalar_read(void)
 
 	// Get the datatype of this dataset.
 	CompType type(dataset);
-     
-	struct space4_struct rdata; 	/* Scalar data read in 		*/
+
+	struct space4_struct rdata; 	// Scalar data read in
 	dataset.read(&rdata, type);
 
 	// Verify read data
 	if(HDmemcmp(&space4_data,&rdata,sizeof(struct space4_struct)))
 	{
-            cerr << "scalar data different: space4_data.c1=" 
+            cerr << "scalar data different: space4_data.c1="
 		<< space4_data.c1 << ", read_data4.c1=" << rdata.c1 << endl;
             cerr << "scalar data different: space4_data.u="
 		<< space4_data.u << ", read_data4.u=" << rdata.u << endl;
@@ -507,20 +502,20 @@ test_h5s_compound_scalar_read(void)
 		<< space4_data.f << ", read_data4.f=" << rdata.f << endl;
             TestErrPrintf("scalar data different: space4_data.c1=%c, read_data4.c1=%c\n",
 		space4_data.c1, rdata.c2);
-	} /* end if */
+	} // end if
     }   // end of try block
-    catch (Exception error)
+    catch (Exception E)
     {
 	// all the exceptions caused by negative returned values by C APIs
-	issue_fail_msg(error.getCFuncName(), __LINE__, __FILE__);
+	issue_fail_msg(E.getCFuncName(), __LINE__, __FILE__, E.getCDetailMsg());
     }
-}				/* test_h5s_compound_scalar_read() */
+}   // test_h5s_compound_scalar_read()
 
 /*-------------------------------------------------------------------------
- *  
+ *
  * Function:	test_h5s
  *
- * Purpose:	Main H5S (dataspace) testing routine
+ * Purpose:	Main dataspace testing routine
  *
  * Return:	none
  *
@@ -530,18 +525,18 @@ test_h5s_compound_scalar_read(void)
  * Modifications:
  *-------------------------------------------------------------------------
  */
-void 
+void
 test_h5s(void)
 {
-    /* Output message about test being performed */
+    // Output message about test being performed
     MESSAGE(5, ("Testing Dataspaces\n"));
 
-    test_h5s_basic();		/* Test basic H5S code */
-    test_h5s_scalar_write();	/* Test scalar H5S writing code */
-    test_h5s_scalar_read();	/* Test scalar H5S reading code */
-    test_h5s_compound_scalar_write();	/* Test compound datatype scalar H5S writing code */
-    test_h5s_compound_scalar_read();	/* Test compound datatype scalar H5S reading code */
-} /* test_h5s() */
+    test_h5s_basic();		// Test basic H5S code
+    test_h5s_scalar_write();	// Test scalar H5S writing code
+    test_h5s_scalar_read();	// Test scalar H5S reading code
+    test_h5s_compound_scalar_write();	// Test compound datatype scalar H5S writing code
+    test_h5s_compound_scalar_read();	// Test compound datatype scalar H5S reading code
+}   // test_h5s()
 
 
 /*-------------------------------------------------------------------------
@@ -562,5 +557,5 @@ void
 cleanup_h5s(void)
 {
     remove(DATAFILE.c_str());
-}
+}   // cleanup_h5s
 
