@@ -82,7 +82,7 @@
      ! Data buffers 
      !         
      INTEGER, DIMENSION(NX,NY) :: data_in, data_out
-     INTEGER, DIMENSION(7) :: data_dims
+     INTEGER(HSIZE_T), DIMENSION(2) :: data_dims
 
      !
      ! Initialize FORTRAN interface. 
