@@ -41,17 +41,17 @@
      TYPE(hdset_reg_ref_t_f) , DIMENSION(2) :: ref_out !
      INTEGER(HSIZE_T), DIMENSION(2) :: dims = (/2,9/)  ! Datasets dimensions
      INTEGER(HSIZE_T), DIMENSION(1) :: dimsr = (/2/)   ! 
-     INTEGER(HSSIZE_T), DIMENSION(2) :: start
+     INTEGER(HSIZE_T), DIMENSION(2) :: start
      INTEGER(HSIZE_T), DIMENSION(2) :: count
      INTEGER :: rankr = 1 
      INTEGER :: rank = 2
      INTEGER , DIMENSION(2,9) ::  data 
      INTEGER , DIMENSION(2,9) ::  data_out = 0 
-     INTEGER(HSSIZE_T) , DIMENSION(2,3) :: coord
+     INTEGER(HSIZE_T) , DIMENSION(2,3) :: coord
      INTEGER(SIZE_T) ::num_points = 3  ! Number of selected points
      INTEGER :: i, j
-     INTEGER, DIMENSION(7) :: ref_size
-     INTEGER, DIMENSION(7) :: data_dims
+     INTEGER(HSIZE_T), DIMENSION(1) :: ref_size
+     INTEGER(HSIZE_T), DIMENSION(2) :: data_dims
      coord = reshape((/1,1,2,7,1,9/), (/2,3/))   ! Coordinates of selected points
      data = reshape ((/1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6/), (/2,9/))
      !
