@@ -85,8 +85,7 @@
      DOUBLE PRECISION,  DIMENSION(1) ::  attr_double_data = 3.459
      REAL,         DIMENSION(1) ::  attr_real_data = 4.0
      INTEGER,      DIMENSION(1) ::  attr_integer_data = 5
-     INTEGER(HSIZE_T), DIMENSION(7) :: data_dims_b
-     INTEGER, DIMENSION(7) :: data_dims
+     INTEGER(HSIZE_T), DIMENSION(7) :: data_dims
 
      
      CHARACTER :: aread_character_data ! variable to put read back Character attr data
@@ -184,7 +183,7 @@
      CALL h5tcopy_f(H5T_NATIVE_CHARACTER, atype2_id, error)
      CALL check("h5tcopy_f",error,total_error)
      !
-     ! Create datatype for the DOulble attribute.
+     ! Create datatype for the Double attribute.
      !
      CALL h5tcopy_f(H5T_NATIVE_DOUBLE, atype3_id, error)
      CALL check("h5tcopy_f",error,total_error)
@@ -255,8 +254,8 @@
      !
      ! Write the Real attribute data.
      !
-     data_dims_b(1) = 1 
-     CALL h5awrite_f(attr4_id, atype4_id, attr_real_data, data_dims_b, error)
+     data_dims(1) = 1 
+     CALL h5awrite_f(attr4_id, atype4_id, attr_real_data, data_dims, error)
      CALL check("h5awrite_f",error,total_error)
 
      !
