@@ -48,9 +48,9 @@
           INTEGER :: rankr = 1 
           TYPE(hobj_ref_t_f), DIMENSION(4) ::  ref
           TYPE(hobj_ref_t_f), DIMENSION(4) ::  ref_out
-          INTEGER, DIMENSION(7) :: ref_dim
+          INTEGER(HSIZE_T), DIMENSION(1) :: ref_dim
           INTEGER, DIMENSION(5) :: data = (/1, 2, 3, 4, 5/)
-          INTEGER, DIMENSION(7) :: data_dims
+          INTEGER(HSIZE_T), DIMENSION(2) :: data_dims
 
 
           !
@@ -219,17 +219,17 @@
           INTEGER     ::   error
           TYPE(hdset_reg_ref_t_f) , DIMENSION(2) :: ref     ! Buffers to store references
           TYPE(hdset_reg_ref_t_f) , DIMENSION(2) :: ref_out !
-          INTEGER, DIMENSION(7) :: ref_dim
-          INTEGER, DIMENSION(7) :: data_dims
+          INTEGER(HSIZE_T), DIMENSION(2) :: ref_dim
+          INTEGER(HSIZE_T), DIMENSION(2) :: data_dims
           INTEGER(HSIZE_T), DIMENSION(2) :: dims = (/2,9/)  ! Datasets dimensions
           INTEGER(HSIZE_T), DIMENSION(1) :: dimsr = (/2/)   ! 
-          INTEGER(HSSIZE_T), DIMENSION(2) :: start
+          INTEGER(HSIZE_T), DIMENSION(2) :: start
           INTEGER(HSIZE_T), DIMENSION(2) :: count
           INTEGER :: rankr = 1 
           INTEGER :: rank = 2
           INTEGER , DIMENSION(2,9) ::  data 
           INTEGER , DIMENSION(2,9) ::  data_out = 0 
-          INTEGER(HSSIZE_T) , DIMENSION(2,3) :: coord
+          INTEGER(HSIZE_T) , DIMENSION(2,3) :: coord
           INTEGER(SIZE_T) ::num_points = 3  ! Number of selected points
           INTEGER :: i, j
           coord = reshape((/1,1,2,7,1,9/), (/2,3/))   ! Coordinates of selected points
