@@ -60,7 +60,7 @@ static void		H5_debug_mask(const char*);
  *   H5_init_library -- Initialize library-global information
  * USAGE
  *    herr_t H5_init_library()
- *   
+ *
  * RETURNS
  *    Non-negative on success/Negative on failure
  *
@@ -69,7 +69,7 @@ static void		H5_debug_mask(const char*);
  *
  *--------------------------------------------------------------------------
  */
-herr_t 
+herr_t
 H5_init_library(void)
 {
     herr_t ret_value=SUCCEED;
@@ -131,7 +131,7 @@ H5_init_library(void)
      * Initialize interfaces that might not be able to initialize themselves
      * soon enough.  The file & dataset interfaces must be initialized because
      * calling H5P_create() might require the file/dataset property classes to be
-     * initialized.  The property interface must be initialized before the file 
+     * initialized.  The property interface must be initialized before the file
      * & dataset interfaces though, in order to provide them with the proper
      * property classes.
      */
@@ -178,7 +178,7 @@ H5_term_library(void)
     unsigned	at=0;
     char	loop[1024];
     H5E_auto_t func;
-    
+
 #ifdef H5_HAVE_THREADSAFE
     /* explicit locking of the API */
     H5_FIRST_THREAD_INIT
@@ -206,7 +206,7 @@ H5_term_library(void)
      (sprintf(loop+at, "..."),						      \
       at += HDstrlen(loop+at),						      \
      n):n))
-    
+
     do {
 	pending = 0;
         /* Try to organize these so the "higher" level components get shut
@@ -268,7 +268,7 @@ H5_term_library(void)
 	H5_MPEinit_g = FALSE;	/* turn it off no matter what */
     }
 #endif
-    
+
     /* Mark library as closed */
     H5_INIT_GLOBAL = FALSE;
 done:
@@ -442,7 +442,7 @@ H5_debug_mask(const char *s)
     char	pkg_name[32], *rest;
     size_t	i;
     int		clear;
-	
+
     while (s && *s) {
 	if (HDisalpha(*s) || '-'==*s || '+'==*s) {
 	    /* Enable or Disable debugging? */
@@ -495,7 +495,7 @@ H5_debug_mask(const char *s)
 	}
     }
 }
-    
+
 
 /*-------------------------------------------------------------------------
  * Function:	H5get_libversion
@@ -571,11 +571,11 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
 
     FUNC_ENTER_API_NOINIT(H5check_version)
     H5TRACE3("e","IuIuIu",majnum,minnum,relnum);
-    
+
     /* Don't check again, if we already have */
     if (checked)
 	HGOTO_DONE(SUCCEED)
-    
+
     {    const char *s;  /* Environment string for disabling version check */
 
         /* Allow different versions of the header files and library? */
@@ -600,8 +600,8 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
 		     stderr);
 	    /* Mention the versions we are referring to */
 	    HDfprintf (stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n",
-		     majnum, minnum, relnum, 
-		     H5_VERS_MAJOR, H5_VERS_MINOR, H5_VERS_RELEASE);
+		     majnum, minnum, relnum,
+		     (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
 
 	    /* Bail out now. */
 	    HDfputs ("Bye...\n", stderr);
@@ -620,8 +620,8 @@ H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
                      "continue.\n", stderr);
 	    /* Mention the versions we are referring to */
 	    HDfprintf (stderr, "Headers are %u.%u.%u, library is %u.%u.%u\n",
-		     majnum, minnum, relnum, 
-		     H5_VERS_MAJOR, H5_VERS_MINOR, H5_VERS_RELEASE);
+		     majnum, minnum, relnum,
+		     (unsigned)H5_VERS_MAJOR, (unsigned)H5_VERS_MINOR, (unsigned)H5_VERS_RELEASE);
 	    break;
         } /* end switch */
 
@@ -844,7 +844,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
     char	*rest, format_templ[128];
     const char	*s;
     va_list	ap;
-    
+
     assert (stream);
     assert (fmt);
 
@@ -883,7 +883,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
 		} /*lint !e744 Switch statement doesn't _need_ default */
 		s++;
 	    }
-	    
+
 	    /* Field width */
 	    if (HDisdigit (*s)) {
 		zerofill = ('0'==*s);
@@ -975,7 +975,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
 	    if (*modifier)
 		sprintf (format_templ+HDstrlen(format_templ), "%s", modifier);
 	    sprintf (format_templ+HDstrlen(format_templ), "%c", conv);
-	    
+
 
 	    /* Conversion */
 	    switch (conv) {
@@ -1162,13 +1162,13 @@ HDstrtoll(const char *s, const char **rest, int base)
 {
     int64_t	sign=1, acc=0;
     hbool_t	overflow = FALSE;
-    
+
     errno = 0;
     if (!s || (base && (base<2 || base>36))) {
 	if (rest) *rest = s;
 	return 0;
     }
-    
+
     /* Skip white space */
     while (HDisspace (*s)) s++;
 
@@ -1177,7 +1177,7 @@ HDstrtoll(const char *s, const char **rest, int base)
 	s++;
     } else if ('-'==*s) {
 	sign = -1;
-	s++; 
+	s++;
     }
 
     /* Zero base prefix */
@@ -1190,7 +1190,7 @@ HDstrtoll(const char *s, const char **rest, int base)
     } else if (0==base) {
 	base = 10;
     }
-    
+
     /* Digits */
     while ((base<=10 && *s>='0' && *s<'0'+base) ||
 	   (base>10 && ((*s>='0' && *s<='9') ||
@@ -1280,16 +1280,16 @@ H5_timer_begin (H5_timer_t *timer)
 #ifdef H5_HAVE_GETRUSAGE
     HDgetrusage (RUSAGE_SELF, &rusage);
     timer->utime = (double)rusage.ru_utime.tv_sec +
-                   (double)rusage.ru_utime.tv_usec/1e6;
+                   ((double)rusage.ru_utime.tv_usec/1e6);
     timer->stime = (double)rusage.ru_stime.tv_sec +
-                   (double)rusage.ru_stime.tv_usec/1e6;
+                   ((double)rusage.ru_stime.tv_usec/1e6);
 #else
     timer->utime = 0.0;
     timer->stime = 0.0;
 #endif
 #ifdef H5_HAVE_GETTIMEOFDAY
     HDgettimeofday (&etime, NULL);
-    timer->etime = (double)etime.tv_sec + (double)etime.tv_usec/1e6;
+    timer->etime = (double)etime.tv_sec + ((double)etime.tv_usec/1e6);
 #else
     timer->etime = 0.0;
 #endif
@@ -1317,7 +1317,7 @@ void
 H5_timer_end (H5_timer_t *sum/*in,out*/, H5_timer_t *timer/*in,out*/)
 {
     H5_timer_t		now;
-    
+
     assert (timer);
     H5_timer_begin (&now);
 
@@ -1350,7 +1350,7 @@ H5_timer_end (H5_timer_t *sum/*in,out*/, H5_timer_t *timer/*in,out*/)
  *			1.2345e-10	For bandwidth less than 1
  *			6.7893e+94	For exceptionally large values
  *			6.678e+106	For really big values
- *			
+ *
  * Return:	void
  *
  * Programmer:	Robb Matzke
@@ -1493,7 +1493,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
     } else {
         HDmemset(&event_time, 0, sizeof event_time);
     }
-    
+
     /* Print the first part of the line.  This is the indication of the
      * nesting depth followed by the function name and either start of
      * argument list or start of return value.  If this call is for a
@@ -1526,7 +1526,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
             fputc('+', out);
         fprintf(out, "%*s%s(", 2*current_depth, "", func);
     }
-    
+
     /* Clear array sizes */
     for (i=0; i<(hssize_t)NELMTS(asize); i++) asize[i] = -1;
 
@@ -1548,7 +1548,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 	} else {
 	    asize_idx = -1;
 	}
-	
+
 	/*
 	 * The argument name.  Leave off the `_id' part.  If the argument
 	 * name is the null pointer then don't print the argument or the
@@ -1558,7 +1558,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 	if (argname) {
 	    unsigned n = (unsigned)MAX (0, (int)HDstrlen(argname)-3); /*lint !e666 Allow expression with side effects */
 	    if (!HDstrcmp (argname+n, "_id")) {
-		HDstrncpy (buf, argname, MIN ((int)sizeof(buf)-1, n));
+		HDstrncpy (buf, argname, (size_t)MIN ((int)sizeof(buf)-1, n));
 		buf[MIN((int)sizeof(buf)-1, n)] = '\0';
 		argname = buf;
 	    }
@@ -1725,7 +1725,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    }
 		}
 		break;
-		
+
 	    case 's':
 		if (ptr) {
 		    if (vp) {
@@ -1754,7 +1754,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    }
 		}
 		break;
-		
+
 	    case 't':
 		if (ptr) {
 		    if (vp) {
@@ -1777,7 +1777,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    }
 		}
 		break;
-		
+
 	    default:
 		fprintf (out, "BADTYPE(D%c)", type[1]);
 		goto error;
@@ -1797,7 +1797,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		else fprintf (out, "FAIL");
 	    }
 	    break;
-	    
+
 	case 'E':
 	    switch (type[1]) {
 	    case 'd':
@@ -1822,7 +1822,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    }
 		}
 		break;
-		
+
 	    case 'e':
 		if (ptr) {
 		    if (vp) {
@@ -1861,7 +1861,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    fprintf(out, "%d", (int)emin);
 		}
 		break;
-		
+
 	    default:
 		fprintf (out, "BADTYPE(E%c)", type[1]);
 		goto error;
@@ -2026,7 +2026,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    asize[argno] = (hssize_t)hssize;
 		}
 		break;
-		
+
 	    default:
 		fprintf (out, "BADTYPE(H%c)", type[1]);
 		goto error;
@@ -2054,9 +2054,6 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
                         case H5I_FILE:
                             fprintf(out, "%ld (file)", (long)obj);
                             break;
-                        case H5I_FILE_CLOSING:
-                            fprintf(out, "%ld (file closing)", (long)obj);
-                            break;
                         case H5I_GROUP:
                             fprintf(out, "%ld (group)", (long)obj);
                             break;
@@ -2214,7 +2211,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    asize[argno] = is;
 		}
 		break;
-		
+
 	    case 'u':
 		if (ptr) {
 		    if (vp) {
@@ -2247,48 +2244,45 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		} else {
 		    H5I_type_t id_type = va_arg (ap, H5I_type_t); /*lint !e64 Type mismatch not really occuring */
 		    switch (id_type) {
-		    case H5I_BADID:
-			fprintf (out, "H5I_BADID");
-			break;
-		    case H5I_FILE:
-			fprintf (out, "H5I_FILE");
-			break;
-		    case H5I_FILE_CLOSING:
-			fprintf (out, "H5I_FILE_CLOSING");
-			break;
-		    case H5I_GROUP:
-			fprintf (out, "H5I_GROUP");
-			break;
-		    case H5I_DATATYPE:
-			fprintf (out, "H5I_DATATYPE");
-			break;
-		    case H5I_DATASPACE:
-			fprintf (out, "H5I_DATASPACE");
-			break;
-		    case H5I_DATASET:
-			fprintf (out, "H5I_DATASET");
-			break;
-		    case H5I_ATTR:
-			fprintf (out, "H5I_ATTR");
-			break;
-		    case H5I_REFERENCE:
-			fprintf (out, "H5I_REFERENCE");
-			break;
-		    case H5I_VFL:
-			fprintf (out, "H5I_VFL");
-			break;
-		    case H5I_GENPROP_CLS:
-			fprintf (out, "H5I_GENPROP_CLS");
-			break;
-		    case H5I_GENPROP_LST:
-			fprintf (out, "H5I_GENPROP_LST");
-			break;
-		    case H5I_NGROUPS:
-			fprintf (out, "H5I_NGROUPS");
-			break;
-		    default:
-			fprintf (out, "%ld", (long)id_type);
-			break;
+                        case H5I_BADID:
+                            fprintf (out, "H5I_BADID");
+                            break;
+                        case H5I_FILE:
+                            fprintf (out, "H5I_FILE");
+                            break;
+                        case H5I_GROUP:
+                            fprintf (out, "H5I_GROUP");
+                            break;
+                        case H5I_DATATYPE:
+                            fprintf (out, "H5I_DATATYPE");
+                            break;
+                        case H5I_DATASPACE:
+                            fprintf (out, "H5I_DATASPACE");
+                            break;
+                        case H5I_DATASET:
+                            fprintf (out, "H5I_DATASET");
+                            break;
+                        case H5I_ATTR:
+                            fprintf (out, "H5I_ATTR");
+                            break;
+                        case H5I_REFERENCE:
+                            fprintf (out, "H5I_REFERENCE");
+                            break;
+                        case H5I_VFL:
+                            fprintf (out, "H5I_VFL");
+                            break;
+                        case H5I_GENPROP_CLS:
+                            fprintf (out, "H5I_GENPROP_CLS");
+                            break;
+                        case H5I_GENPROP_LST:
+                            fprintf (out, "H5I_GENPROP_LST");
+                            break;
+                        case H5I_NGROUPS:
+                            fprintf (out, "H5I_NGROUPS");
+                            break;
+                        default:
+                            fprintf (out, "%ld", (long)id_type);
+                            break;
 		    }
 		}
 		break;
@@ -2462,7 +2456,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
                         }
                     }
                     break;
-                            
+
                 default:
                     fprintf(out, "BADTYPE(S%c)", type[1]);
                     goto error;
@@ -2499,7 +2493,7 @@ H5_trace (const double *returning, const char *func, const char *type, ...)
 		    }
 		}
 		break;
-			
+
 	    case 's':
 		if (ptr) {
 		    if (vp) {
