@@ -47,7 +47,7 @@
  *			   e. left[x] is a pointer to the node's left sibling
  *			      or the null pointer if this is the left-most
  *			      node at this level in the tree.
- *			      
+ *
  *			   f. right[x] is a pointer to the node's right
  *			      sibling or the null pointer if this is the
  *			      right-most node at this level in the tree.
@@ -229,7 +229,7 @@ H5B_create(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, void *udata,
     shared=H5RC_GET_OBJ(bt->rc_shared);
     HDassert(shared);
     if (NULL==(bt->native=H5FL_BLK_MALLOC(native_block,shared->sizeof_keys)) ||
-            NULL==(bt->child=H5FL_SEQ_MALLOC(haddr_t,shared->two_k)))
+            NULL==(bt->child=H5FL_SEQ_MALLOC(haddr_t,(size_t)shared->two_k)))
 	HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for B-tree root node")
     if (HADDR_UNDEF==(*addr_p=H5MF_alloc(f, H5FD_MEM_BTREE, dxpl_id, (hsize_t)shared->sizeof_rnode)))
 	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "file allocation failed for B-tree root node")
@@ -242,7 +242,7 @@ H5B_create(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, void *udata,
 #ifdef H5B_DEBUG
     H5B_assert(f, dxpl_id, *addr_p, shared->type, udata);
 #endif
-    
+
 done:
     if (ret_value<0) {
         if(shared && shared->sizeof_rnode>0) {
@@ -252,7 +252,7 @@ done:
 	if (bt)
             (void)H5B_dest(f,bt);
     }
-    
+
     FUNC_LEAVE_NOAPI(ret_value)
 } /*lint !e818 Can't make udata a pointer to const */
 
@@ -306,7 +306,7 @@ H5B_load(H5F_t *f, hid_t dxpl_id, haddr_t addr, const void *_type, void *udata)
     shared=H5RC_GET_OBJ(bt->rc_shared);
     HDassert(shared);
     if (NULL==(bt->native=H5FL_BLK_MALLOC(native_block,shared->sizeof_keys)) ||
-            NULL==(bt->child=H5FL_SEQ_MALLOC(haddr_t,shared->two_k)))
+            NULL==(bt->child=H5FL_SEQ_MALLOC(haddr_t,(size_t)shared->two_k)))
 	HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
     if (H5F_block_read(f, H5FD_MEM_BTREE, addr, shared->sizeof_rnode, dxpl_id, shared->page)<0)
@@ -315,7 +315,7 @@ H5B_load(H5F_t *f, hid_t dxpl_id, haddr_t addr, const void *_type, void *udata)
     p = shared->page;
 
     /* magic number */
-    if (HDmemcmp(p, H5B_MAGIC, H5B_SIZEOF_MAGIC))
+    if (HDmemcmp(p, H5B_MAGIC, (size_t)H5B_SIZEOF_MAGIC))
 	HGOTO_ERROR(H5E_BTREE, H5E_CANTLOAD, NULL, "wrong B-tree signature")
     p += 4;
 
@@ -399,7 +399,7 @@ H5B_serialize(const H5F_t *f, const H5B_t *bt)
     p = shared->page;
 
     /* magic number */
-    HDmemcpy(p, H5B_MAGIC, H5B_SIZEOF_MAGIC);
+    HDmemcpy(p, H5B_MAGIC, (size_t)H5B_SIZEOF_MAGIC);
     p += 4;
 
     /* node type and level */
@@ -571,7 +571,7 @@ H5B_clear(H5F_t *f, H5B_t *bt, hbool_t destroy)
 
     /* Reset the dirty flag.  */
     bt->cache_info.is_dirty = FALSE;
- 
+
     if (destroy)
         if (H5B_dest(f, bt) < 0)
 	    HGOTO_ERROR(H5E_BTREE, H5E_CANTFREE, FAIL, "unable to destroy B-tree node")
@@ -584,8 +584,8 @@ done:
 /*-------------------------------------------------------------------------
  * Function:	H5B_compute_size
  *
- * Purpose:	Compute the size in bytes of the specified instance of 
- *		H5B_t on disk, and return it in *len_ptr.  On failure, 
+ * Purpose:	Compute the size in bytes of the specified instance of
+ *		H5B_t on disk, and return it in *len_ptr.  On failure,
  *		the value of *len_ptr is undefined.
  *
  * Return:	Non-negative on success/Negative on failure
@@ -704,7 +704,7 @@ H5B_find(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr, void *u
 #else /* OLD_WAY */
 	HGOTO_DONE(FAIL)
 #endif /* OLD_WAY */
-    
+
     /*
      * Follow the link to the subtree or to the data node.
      */
@@ -848,7 +848,7 @@ H5B_split(H5F_t *f, hid_t dxpl_id, H5B_t *old_bt, haddr_t old_addr,
     if (H5DEBUG(B))
 	fprintf(H5DEBUG(B), " split %3d/%-3d\n", nleft, nright);
 #endif
-    
+
     /*
      * Create the new B-tree node.
      */
@@ -875,7 +875,7 @@ H5B_split(H5F_t *f, hid_t dxpl_id, H5B_t *old_bt, haddr_t old_addr,
      */
     old_bt->cache_info.is_dirty = TRUE;
     old_bt->nchildren = nleft;
-    
+
     /*
      * Update sibling pointers.
      */
@@ -982,14 +982,14 @@ H5B_insert(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr,
         HGOTO_ERROR(H5E_BTREE, H5E_PROTECT, FAIL, "unable to release new child")
 
     bt = NULL;
-    
+
     /* the new node */
     if (NULL == (bt = H5AC_protect(f, dxpl_id, H5AC_BT, child, type, udata, H5AC_READ)))
 	HGOTO_ERROR(H5E_BTREE, H5E_CANTLOAD, FAIL, "unable to load new node")
 
     if (!rt_key_changed)
 	HDmemcpy(rt_key, H5B_NKEY(bt,shared,bt->nchildren), type->sizeof_nkey);
-    
+
     if (H5AC_unprotect(f, dxpl_id, H5AC_BT, child, bt, FALSE) != SUCCEED)
         HGOTO_ERROR(H5E_BTREE, H5E_PROTECT, FAIL, "unable to release new child")
 
@@ -1071,11 +1071,11 @@ H5B_insert(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr,
 #ifdef H5B_DEBUG
     H5B_assert(f, dxpl_id, addr, type, udata);
 #endif
-    
+
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 }
-    
+
 
 /*-------------------------------------------------------------------------
  * Function:	H5B_insert_child
@@ -1422,7 +1422,7 @@ H5B_insert_helper(H5F_t *f, hid_t dxpl_id, haddr_t addr, const H5B_class_t *type
 	if (H5B_insert_child(tmp_bt, idx, child_addr, my_ins, md_key) < 0)
 	    HGOTO_ERROR(H5E_BTREE, H5E_CANTINSERT, H5B_INS_ERROR, "can't insert child")
     }
-    
+
     /*
      * If this node split, return the mid key (the one that is shared
      * by the left and right node).
@@ -1492,7 +1492,7 @@ H5B_iterate (H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, H5B_operator_t op
     unsigned            level;
     haddr_t             left_child;
     herr_t		ret_value;
-    
+
     FUNC_ENTER_NOAPI(H5B_iterate, FAIL)
 
     /*
@@ -1526,7 +1526,7 @@ H5B_iterate (H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, H5B_operator_t op
 	 * We've reached the left-most leaf.  Now follow the right-sibling
 	 * pointer from leaf to leaf until we've processed all leaves.
 	 */
-	if (NULL==(child=H5FL_SEQ_MALLOC(haddr_t,shared->two_k)) ||
+	if (NULL==(child=H5FL_SEQ_MALLOC(haddr_t,(size_t)shared->two_k)) ||
                 NULL==(key=H5FL_BLK_MALLOC(native_block,shared->sizeof_keys)))
 	    HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
 
@@ -1610,7 +1610,7 @@ H5B_remove_helper(H5F_t *f, hid_t dxpl_id, haddr_t addr, const H5B_class_t *type
     unsigned    idx=0, lt=0, rt;        /* Final, left & right indices */
     int         cmp=1;                  /* Key comparison value */
     H5B_ins_t	ret_value = H5B_INS_ERROR;
-    
+
     FUNC_ENTER_NOAPI(H5B_remove_helper, H5B_INS_ERROR)
 
     assert(f);
@@ -1785,7 +1785,7 @@ H5B_remove_helper(H5F_t *f, hid_t dxpl_id, haddr_t addr, const H5B_class_t *type
 	 */
 	bt->cache_info.is_dirty = TRUE;
 	bt->nchildren -= 1;
-	
+
 	HDmemmove(bt->native,
 		  bt->native + type->sizeof_nkey,
 		  (bt->nchildren+1) * type->sizeof_nkey);
@@ -1839,7 +1839,7 @@ H5B_remove_helper(H5F_t *f, hid_t dxpl_id, haddr_t addr, const H5B_class_t *type
 	 */
 	bt->cache_info.is_dirty = TRUE;
 	bt->nchildren -= 1;
-	
+
 	HDmemmove(bt->native + idx * type->sizeof_nkey,
 		  bt->native + (idx+1) * type->sizeof_nkey,
 		  (bt->nchildren+1-idx) * type->sizeof_nkey);
@@ -1847,7 +1847,7 @@ H5B_remove_helper(H5F_t *f, hid_t dxpl_id, haddr_t addr, const H5B_class_t *type
 		  bt->child+idx+1,
 		  (bt->nchildren-idx) * sizeof(haddr_t));
 	ret_value = H5B_INS_NOOP;
-	
+
     } else {
 	ret_value = H5B_INS_NOOP;
     }
@@ -1890,7 +1890,7 @@ H5B_remove(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr, void
     hbool_t	rt_key_changed = FALSE;		/*right key changed?*/
     H5B_t	*bt = NULL;			/*btree node */
     herr_t      ret_value=SUCCEED;       /* Return value */
-    
+
     FUNC_ENTER_NOAPI(H5B_remove, FAIL)
 
     /* Check args */
@@ -1915,7 +1915,7 @@ H5B_remove(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr, void
 	bt->level = 0;
 	bt->cache_info.is_dirty = TRUE;
     }
-    
+
     if (H5AC_unprotect(f, dxpl_id, H5AC_BT, addr, bt, FALSE) != SUCCEED)
         HGOTO_ERROR(H5E_BTREE, H5E_PROTECT, FAIL, "unable to release node")
 
@@ -1951,7 +1951,7 @@ H5B_delete(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr, void
     H5B_shared_t        *shared;        /* Pointer to shared B-tree info */
     unsigned    u;                      /* Local index variable */
     herr_t      ret_value=SUCCEED;      /* Return value */
-    
+
     FUNC_ENTER_NOAPI(H5B_delete, FAIL)
 
     /* Check args */
@@ -1991,7 +1991,7 @@ H5B_delete(H5F_t *f, hid_t dxpl_id, const H5B_class_t *type, haddr_t addr, void
     /* Delete this node from disk */
     if (H5MF_xfree(f, H5FD_MEM_BTREE, dxpl_id, addr, (hsize_t)shared->sizeof_rnode)<0)
         HGOTO_ERROR(H5E_BTREE, H5E_CANTFREE, FAIL, "unable to free B-tree node")
-    
+
 done:
     if (bt && H5AC_unprotect(f, dxpl_id, H5AC_BT, addr, bt, TRUE)<0)
         HDONE_ERROR(H5E_BTREE, H5E_PROTECT, FAIL, "unable to release B-tree node in cache")
@@ -2097,7 +2097,7 @@ H5B_copy(const H5B_t *old_bt)
     HDmemcpy(new_node,old_bt,sizeof(H5B_t));
 
     if ( NULL==(new_node->native=H5FL_BLK_MALLOC(native_block,shared->sizeof_keys)) ||
-            NULL==(new_node->child=H5FL_SEQ_MALLOC(haddr_t,shared->two_k)))
+            NULL==(new_node->child=H5FL_SEQ_MALLOC(haddr_t,(size_t)shared->two_k)))
         HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for B-tree root node")
 
     /* Copy the other structures */
@@ -2207,7 +2207,7 @@ H5B_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int indent, int f
 	HDfprintf(stream, "%*sChild %d...\n", indent, "", u);
 	HDfprintf(stream, "%*s%-*s %a\n", indent + 3, "", MAX(0, fwidth - 3),
 		  "Address:", bt->child[u]);
-	
+
         /* If there is a key debugging routine, use it to display the left & right keys */
 	if (type->debug_key) {
             /* Decode the 'left' key & print it */
