@@ -114,7 +114,7 @@ NAME
    H5FL_init_interface -- Initialize interface-specific information
 USAGE
     herr_t H5FL_init_interface()
-   
+
 RETURNS
     Non-negative on success/Negative on failure
 DESCRIPTION
@@ -147,7 +147,7 @@ H5FL_init_interface(void)
  *              Tuesday, August 1, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static void *
@@ -186,7 +186,7 @@ done:
  *              Friday, March 24, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -232,7 +232,7 @@ done:
  *              Friday, March 24, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -298,7 +298,7 @@ done:
  *              Friday, March 24, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -358,7 +358,7 @@ done:
  *              Monday, December 23, 2002
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -395,7 +395,7 @@ done:
  *              Tuesday, July 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -404,7 +404,7 @@ H5FL_reg_gc_list(H5FL_reg_head_t *head)
     H5FL_reg_node_t *free_list; /* Pointer to nodes in free list being garbage collected */
     void *tmp;          /* Temporary node pointer */
     size_t total_mem;   /* Total memory used on list */
-    
+
     FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5FL_reg_gc_list)
 
     /* Calculate the total memory used on this list */
@@ -454,7 +454,7 @@ H5FL_reg_gc_list(H5FL_reg_head_t *head)
  * Modifications:
  *  Broke into two parts, one for looping over all the free lists and
  *      another for freeing each list - QAK 7/25/00
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -462,7 +462,7 @@ H5FL_reg_gc(void)
 {
     H5FL_reg_gc_node_t *gc_node;    /* Pointer into the list of things to garbage collect */
     herr_t ret_value=SUCCEED;   /* return value*/
-    
+
     FUNC_ENTER_NOAPI_NOINIT(H5FL_reg_gc)
 
     /* Walk through all the free lists, free()'ing the nodes */
@@ -614,7 +614,7 @@ H5FL_blk_find_list(H5FL_blk_node_t **head, size_t size)
             temp=temp->next;
         } /* end while */
     } /* end if */
-    
+
     FUNC_LEAVE_NOAPI(temp)
 } /* end H5FL_blk_find_list() */
 
@@ -647,7 +647,7 @@ H5FL_blk_create_list(H5FL_blk_node_t **head, size_t size)
     /* Allocate room for the new free list node */
     if(NULL==(temp=H5FL_MALLOC(H5FL_blk_node_t)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for chunk info")
-    
+
     /* Set the correct values for the new free list */
     temp->size=size;
     temp->list=NULL;
@@ -684,7 +684,7 @@ done:
  *              Saturday, March 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -810,7 +810,7 @@ H5FL_blk_malloc(H5FL_blk_head_t *head, size_t size)
 
     } /* end if */
     /* No free list available, or there are no nodes on the list, allocate a new node to give to the user */
-    else { 
+    else {
         /* Allocate new node, with room for the page info header and the actual page data */
         if(NULL==(temp=H5FL_malloc(sizeof(H5FL_blk_list_t)+size)))
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for chunk")
@@ -1014,7 +1014,7 @@ done:
  *              Thursday, March 23, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1023,7 +1023,7 @@ H5FL_blk_gc_list(H5FL_blk_head_t *head)
     H5FL_blk_list_t *list; /* The free list of native nodes of a particular size */
     void *next;     /* Temp. ptr to the free list list node */
     void *temp;     /* Temp. ptr to the free list page node */
-    
+
     FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5FL_blk_gc_list)
 
     /* Loop through all the nodes in the block free list queue */
@@ -1078,7 +1078,7 @@ H5FL_blk_gc_list(H5FL_blk_head_t *head)
  *              Saturday, March 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1086,7 +1086,7 @@ H5FL_blk_gc(void)
 {
     H5FL_blk_gc_node_t *gc_node;    /* Pointer into the list of things to garbage collect */
     herr_t ret_value=SUCCEED;   /* return value*/
-    
+
     FUNC_ENTER_NOAPI_NOINIT(H5FL_blk_gc)
 
     /* Walk through all the free lists, free()'ing the nodes */
@@ -1134,7 +1134,7 @@ H5FL_blk_term(void)
     H5FL_blk_gc_node_t *tmp;    /* Temporary pointer to a garbage collection node */
 
     FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5FL_blk_term)
-    
+
     /* Free the nodes on the garbage collection list, keeping nodes with allocations outstanding */
     left=NULL;
     while(H5FL_blk_gc_head.first!=NULL) {
@@ -1164,7 +1164,7 @@ printf("H5FL_blk_term: head->name=%s, head->allocated=%d\n", H5FL_blk_gc_head.fi
 
     /* Point to the list of nodes left with allocations open, if any */
     H5FL_blk_gc_head.first=left;
-    
+
     FUNC_LEAVE_NOAPI(H5FL_blk_gc_head.first!=NULL ? 1 : 0)
 }   /* end H5FL_blk_term() */
 
@@ -1182,7 +1182,7 @@ printf("H5FL_blk_term: head->name=%s, head->allocated=%d\n", H5FL_blk_gc_head.fi
  *              Saturday, March 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1210,9 +1210,9 @@ H5FL_arr_init(H5FL_arr_head_t *head)
         HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
 
     /* Initialize the size of each array */
-    for(u=1; u<(size_t)head->maxelem; u++)
-        head->list_arr[u].size=head->size*u;
-    
+    for(u = 0; u<(size_t)head->maxelem; u++)
+        head->list_arr[u].size = head->base_size + (head->elem_size * u);
+
     /* Indicate that the free list is initialized */
     head->init=1;
 
@@ -1233,7 +1233,7 @@ done:
  *              Friday, March 24, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1309,7 +1309,7 @@ done:
  *              Saturday, March 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1384,7 +1384,7 @@ done:
  *              Monday, December 23, 2002
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1422,7 +1422,7 @@ done:
  *              Saturday, March 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1456,7 +1456,7 @@ H5FL_arr_realloc(H5FL_arr_head_t *head, void * obj, size_t new_elem)
             ret_value=H5FL_arr_malloc(head,new_elem);
 
             /* Copy the appropriate amount of elements */
-            blk_size=head->size*MIN(temp->nelem,new_elem);
+            blk_size = head->list_arr[ MIN(temp->nelem, new_elem) ].size;
             HDmemcpy(ret_value,obj,blk_size);
 
             /* Free the old block */
@@ -1483,7 +1483,7 @@ done:
  *              Tuesday, July 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1493,7 +1493,7 @@ H5FL_arr_gc_list(H5FL_arr_head_t *head)
     void *tmp;      /* Temporary node pointer */
     unsigned u;     /* Counter for array of free lists */
     size_t total_mem;   /* Total memory used on list */
-    
+
     FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5FL_arr_gc_list)
 
     /* Walk through the array of free lists */
@@ -1545,7 +1545,7 @@ H5FL_arr_gc_list(H5FL_arr_head_t *head)
  *              Saturday, March 25, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1553,7 +1553,7 @@ H5FL_arr_gc(void)
 {
     H5FL_gc_arr_node_t *gc_arr_node;    /* Pointer into the list of things to garbage collect */
     herr_t ret_value=SUCCEED;   /* return value*/
-    
+
     FUNC_ENTER_NOAPI_NOINIT(H5FL_arr_gc)
 
     /* Walk through all the free lists, free()'ing the nodes */
@@ -1599,7 +1599,7 @@ H5FL_arr_term(void)
 {
     H5FL_gc_arr_node_t *left;   /* pointer to garbage collection lists with work left */
     H5FL_gc_arr_node_t *tmp;    /* Temporary pointer to a garbage collection node */
-    
+
     FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5FL_arr_term)
 
     /* Free the nodes on the garbage collection list, keeping nodes with allocations outstanding */
@@ -1633,7 +1633,7 @@ printf("H5FL_arr_term: head->name=%s, head->allocated=%d\n", H5FL_arr_gc_head.fi
 
     /* Point to the list of nodes left with allocations open, if any */
     H5FL_arr_gc_head.first=left;
-    
+
     FUNC_LEAVE_NOAPI(H5FL_arr_gc_head.first!=NULL ? 1 : 0)
 }   /* end H5FL_arr_term() */
 
@@ -1650,7 +1650,7 @@ printf("H5FL_arr_term: head->name=%s, head->allocated=%d\n", H5FL_arr_gc_head.fi
  *              Saturday, April 3, 2004
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1684,7 +1684,7 @@ H5FL_seq_free(H5FL_seq_head_t *head, void *obj)
  *              Saturday, April 3, 2004
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1718,7 +1718,7 @@ done:
  *              Saturday, April 3, 2004
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1752,7 +1752,7 @@ done:
  *              Saturday, April 3, 2004
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 void *
@@ -1786,7 +1786,7 @@ done:
  *              Friday, March 24, 2000
  *
  * Modifications:
- * 	
+ *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -1842,7 +1842,7 @@ done:
  *
  *-------------------------------------------------------------------------
  */
-herr_t 
+herr_t
 H5FL_set_free_list_limits(int reg_global_lim, int reg_list_lim, int arr_global_lim,
     int arr_list_lim, int blk_global_lim, int blk_list_lim)
 {
@@ -1892,7 +1892,7 @@ int
 H5FL_term_interface(void)
 {
     int ret_value=0;
-    
+
     FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5FL_term_interface)
 
     /* Garbage collect any nodes on the free lists */
