@@ -16,22 +16,26 @@
  * Programmer: Robb Matzke <matzke@llnl.gov>
  *             Friday, September 19, 1997
  */
-#define H5G_PACKAGE
+#define H5G_PACKAGE		/*suppress error about including H5Gpkg	  */
 #define H5F_PACKAGE		/*suppress error about including H5Fpkg	  */
 
 
+/* Packages needed by this file... */
 #include "H5private.h"		/* Generic Functions			*/
 #include "H5Eprivate.h"		/* Error handling		  	*/
 #include "H5Fpkg.h"             /* File access				*/
+#include "H5FLprivate.h"	/* Free Lists                           */
 #include "H5Gpkg.h"		/* Groups		  		*/
 #include "H5HLprivate.h"	/* Local Heaps				*/
-#include "H5MMprivate.h"	/* Memory management			*/
 
 /* Private prototypes */
 #ifdef NOT_YET
 static herr_t H5G_ent_modified(H5G_entry_t *ent, H5G_type_t cache_type);
 #endif /* NOT_YET */
 
+/* Declare extern the PQ free list for the wrapped strings */
+H5FL_BLK_EXTERN(str_buf);
+
 
 /*-------------------------------------------------------------------------
  * Function:    H5G_ent_cache
@@ -52,10 +56,10 @@ static herr_t H5G_ent_modified(H5G_entry_t *ent, H5G_type_t cache_type);
  *
  *-------------------------------------------------------------------------
  */
-H5G_cache_t            *
-H5G_ent_cache(H5G_entry_t *ent, H5G_type_t *cache_type)
+const H5G_cache_t *
+H5G_ent_cache(const H5G_entry_t *ent, H5G_type_t *cache_type)
 {
-    H5G_cache_t *ret_value;     /* Return value */
+    const H5G_cache_t *ret_value;     /* Return value */
 
     FUNC_ENTER_NOAPI(H5G_ent_cache, NULL);
 
@@ -65,7 +69,7 @@ H5G_ent_cache(H5G_entry_t *ent, H5G_type_t *cache_type)
         *cache_type = ent->type;
 
     /* Set return value */
-    ret_value=&(ent->cache);
+    ret_value=(const H5G_cache_t *)&(ent->cache);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value);
@@ -94,19 +98,17 @@ done:
 static herr_t
 H5G_ent_modified(H5G_entry_t *ent, H5G_type_t cache_type)
 {
-    herr_t ret_value=SUCCEED;   /* Return value */
+    FUNC_ENTER_NOAPI_NOFUNC(H5G_ent_modified)
 
-    FUNC_ENTER_NOAPI(H5G_ent_modified, FAIL);
+    HDassert(ent);
 
-    assert(ent);
-
-    if (H5G_NO_CHANGE != ent->type)
+    /* Update cache type, if requested */
+    if (H5G_NO_CHANGE != cache_type)
         ent->type = cache_type;
     ent->dirty = TRUE;
 
-done:
-    FUNC_LEAVE_NOAPI(ret_value);
-}
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5G_ent_modified */
 #endif /* NOT_YET */
 
 
@@ -117,7 +119,7 @@ done:
  *              symbol table entries.
  *
  * Errors:
- *              SYM       CANTDECODE    Can't decode. 
+ *              SYM       CANTDECODE    Can't decode.
  *
  * Return:      Success:        Non-negative, with *pp pointing to the first byte
  *                              after the last symbol.
@@ -133,9 +135,9 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G_ent_decode_vec(H5F_t *f, const uint8_t **pp, H5G_entry_t *ent, int n)
+H5G_ent_decode_vec(H5F_t *f, const uint8_t **pp, H5G_entry_t *ent, unsigned n)
 {
-    int                    i;
+    unsigned    u;
     herr_t      ret_value=SUCCEED;       /* Return value */
 
     FUNC_ENTER_NOAPI(H5G_ent_decode_vec, FAIL);
@@ -144,13 +146,11 @@ H5G_ent_decode_vec(H5F_t *f, const uint8_t **pp, H5G_entry_t *ent, int n)
     assert(f);
     assert(pp);
     assert(ent);
-    assert(n >= 0);
 
     /* decode entries */
-    for (i = 0; i < n; i++) {
-        if (H5G_ent_decode(f, pp, ent + i) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_CANTDECODE, FAIL, "can't decode");
-    }
+    for (u = 0; u < n; u++)
+        if (H5G_ent_decode(f, pp, ent + u) < 0)
+            HGOTO_ERROR(H5E_SYM, H5E_CANTDECODE, FAIL, "can't decode")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value);
@@ -203,21 +203,21 @@ H5G_ent_decode(H5F_t *f, const uint8_t **pp, H5G_entry_t *ent)
 
     /* decode scratch-pad */
     switch (ent->type) {
-    case H5G_NOTHING_CACHED:
-        break;
+        case H5G_NOTHING_CACHED:
+            break;
 
-    case H5G_CACHED_STAB:
-        assert(2 * H5F_SIZEOF_ADDR(f) <= H5G_SIZEOF_SCRATCH);
-        H5F_addr_decode(f, pp, &(ent->cache.stab.btree_addr));
-        H5F_addr_decode(f, pp, &(ent->cache.stab.heap_addr));
-        break;
+        case H5G_CACHED_STAB:
+            assert(2 * H5F_SIZEOF_ADDR(f) <= H5G_SIZEOF_SCRATCH);
+            H5F_addr_decode(f, pp, &(ent->cache.stab.btree_addr));
+            H5F_addr_decode(f, pp, &(ent->cache.stab.heap_addr));
+            break;
 
-    case H5G_CACHED_SLINK:
-	UINT32DECODE (*pp, ent->cache.slink.lval_offset);
-	break;
+        case H5G_CACHED_SLINK:
+            UINT32DECODE (*pp, ent->cache.slink.lval_offset);
+            break;
 
-    default:
-        HDabort();
+        default:
+            HDabort();
     }
 
     *pp = p_ret + H5G_SIZEOF_ENTRY(f);
@@ -233,7 +233,7 @@ H5G_ent_decode(H5F_t *f, const uint8_t **pp, H5G_entry_t *ent)
  *              symbol table entries.
  *
  * Errors:
- *              SYM       CANTENCODE    Can't encode. 
+ *              SYM       CANTENCODE    Can't encode.
  *
  * Return:      Success:        Non-negative, with *pp pointing to the first byte
  *                              after the last symbol.
@@ -249,9 +249,9 @@ H5G_ent_decode(H5F_t *f, const uint8_t **pp, H5G_entry_t *ent)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5G_ent_encode_vec(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent, int n)
+H5G_ent_encode_vec(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent, unsigned n)
 {
-    int                    i;
+    unsigned    u;
     herr_t      ret_value=SUCCEED;       /* Return value */
 
     FUNC_ENTER_NOAPI(H5G_ent_encode_vec, FAIL);
@@ -260,13 +260,11 @@ H5G_ent_encode_vec(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent, int n)
     assert(f);
     assert(pp);
     assert(ent);
-    assert(n >= 0);
 
     /* encode entries */
-    for (i = 0; i < n; i++) {
-        if (H5G_ent_encode(f, pp, ent + i) < 0)
+    for (u = 0; u < n; u++)
+        if (H5G_ent_encode(f, pp, ent + u) < 0)
             HGOTO_ERROR(H5E_SYM, H5E_CANTENCODE, FAIL, "can't encode");
-    }
 
 done:
     FUNC_LEAVE_NOAPI(ret_value);
@@ -344,7 +342,7 @@ H5G_ent_encode(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent)
     /* fill with zero */
     while (*pp < p_ret) *(*pp)++ = 0;
     *pp = p_ret;
-    
+
     FUNC_LEAVE_NOAPI(SUCCEED);
 }
 
@@ -360,7 +358,7 @@ H5G_ent_encode(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent)
  *
  * Date: August 2002
  *
- * Comments: 
+ * Comments:
  *
  * Modifications:
  *      Quincey Koziol, Sept. 25, 2002:
@@ -377,7 +375,8 @@ H5G_ent_encode(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent)
  *                      previous value in the destination.
  *                  H5G_COPY_SHALLOW - Copy all the fields from the source
  *                      to the destination, including the user path and
- *                      canonical path.
+ *                      canonical path. (Destination "takes ownership" of
+ *                      user and canonical paths)
  *                  H5G_COPY_DEEP - Copy all the fields from the source to
  *                      the destination, deep copying the user and canonical
  *                      paths.
@@ -398,7 +397,8 @@ H5G_ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5G_ent_copy_depth_t dept
     /* If the depth is "very shallow", keep the old entry's user path */
     if(depth==H5G_COPY_LIMITED) {
         tmp_user_path_r=dst->user_path_r;
-        H5RS_decr(dst->canon_path_r);
+        if(dst->canon_path_r)
+            H5RS_decr(dst->canon_path_r);
     } /* end if */
 
     /* Copy the top level information */
@@ -414,11 +414,167 @@ H5G_ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5G_ent_copy_depth_t dept
     } else if(depth==H5G_COPY_NULL) {
         dst->user_path_r=NULL;
         dst->canon_path_r=NULL;
+    } else if(depth==H5G_COPY_SHALLOW) {
+#ifndef NDEBUG
+        /* Discarding 'const' qualifier OK - QAK */
+        H5G_ent_reset((H5G_entry_t *)src);
+#endif /* NDEBUG */
     } /* end if */
 
     FUNC_LEAVE_NOAPI(SUCCEED);
 }
 
+
+/*-------------------------------------------------------------------------
+ * Function: H5G_ent_reset
+ *
+ * Purpose: Reset a symbol table entry to an empty state
+ *
+ * Return: Success: 0, Failure: -1
+ *
+ * Programmer: Quincey Koziol, koziol@ncsa.uiuc.edu
+ *
+ * Date: August 2005
+ *
+ * Comments:
+ *
+ * Modifications:
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5G_ent_reset(H5G_entry_t *ent)
+{
+    FUNC_ENTER_NOAPI_NOFUNC(H5G_ent_reset);
+
+    /* Check arguments */
+    HDassert(ent);
+
+    /* Clear the symbol table entry to an empty state */
+    HDmemset(ent, 0, sizeof(H5G_entry_t));
+    ent->header = HADDR_UNDEF;
+
+    FUNC_LEAVE_NOAPI(SUCCEED);
+} /* end H5G_ent_reset() */
+
+
+/*-------------------------------------------------------------------------
+ * Function: H5G_ent_set_name
+ *
+ * Purpose: Set the name of a symbol entry OBJ, located at LOC
+ *
+ * Return: Success: 0, Failure: -1
+ *
+ * Programmer: Pedro Vicente, pvn@ncsa.uiuc.edu
+ *
+ * Date: August 22, 2002
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5G_ent_set_name(H5G_entry_t *loc, H5G_entry_t *obj, const char *name)
+{
+    size_t  name_len;           /* Length of name to append */
+    herr_t  ret_value = SUCCEED;
+
+    FUNC_ENTER_NOAPI(H5G_ent_set_name, FAIL)
+
+    assert(loc);
+    assert(obj);
+    assert(name);
+
+    /* Reset the object's previous names, if they exist */
+    if(obj->user_path_r) {
+        H5RS_decr(obj->user_path_r);
+        obj->user_path_r=NULL;
+    } /* end if */
+    if(obj->canon_path_r) {
+        H5RS_decr(obj->canon_path_r);
+        obj->canon_path_r=NULL;
+    } /* end if */
+    obj->user_path_hidden=0;
+
+    /* Get the length of the new name */
+    name_len = HDstrlen(name);
+
+    /* Modify the object's user path, if a user path exists in the location */
+    if(loc->user_path_r) {
+        const char *loc_user_path;      /* Pointer to raw string for user path */
+        size_t  user_path_len;      /* Length of location's user path name */
+        char *new_user_path;        /* Pointer to new user path */
+
+        /* Get the length of the strings involved */
+        user_path_len = H5RS_len(loc->user_path_r);
+
+        /* Modify the object's user path */
+
+        /* Get the raw string for the user path */
+        loc_user_path=H5RS_get_str(loc->user_path_r);
+        assert(loc_user_path);
+
+        /* The location's user path already ends in a '/' separator */
+        if ('/'==loc_user_path[user_path_len-1]) {
+            if (NULL==(new_user_path = H5FL_BLK_MALLOC(str_buf,user_path_len+name_len+1)))
+                HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HDstrcpy(new_user_path, loc_user_path);
+        } /* end if */
+        /* The location's user path needs a separator */
+        else {
+            if (NULL==(new_user_path = H5FL_BLK_MALLOC(str_buf,user_path_len+1+name_len+1)))
+                HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HDstrcpy(new_user_path, loc_user_path);
+            HDstrcat(new_user_path, "/");
+        } /* end else */
+
+        /* Append the component's name */
+        HDstrcat(new_user_path, name);
+
+        /* Give ownership of the user path to the entry */
+        obj->user_path_r=H5RS_own(new_user_path);
+        assert(obj->user_path_r);
+    } /* end if */
+
+    /* Modify the object's canonical path, if a canonical path exists in the location */
+    if(loc->canon_path_r) {
+        const char *loc_canon_path;     /* Pointer to raw string for canonical path */
+        size_t  canon_path_len;     /* Length of location's canonical path name */
+        char *new_canon_path;       /* Pointer to new canonical path */
+
+        /* Get the length of the strings involved */
+        canon_path_len = H5RS_len(loc->canon_path_r);
+
+        /* Modify the object's canonical path */
+
+        /* Get the raw string for the canonical path */
+        loc_canon_path=H5RS_get_str(loc->canon_path_r);
+        assert(loc_canon_path);
+
+        /* The location's canonical path already ends in a '/' separator */
+        if ('/'==loc_canon_path[canon_path_len-1]) {
+            if (NULL==(new_canon_path = H5FL_BLK_MALLOC(str_buf,canon_path_len+name_len+1)))
+                HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HDstrcpy(new_canon_path, loc_canon_path);
+        } /* end if */
+        /* The location's canonical path needs a separator */
+        else {
+            if (NULL==(new_canon_path = H5FL_BLK_MALLOC(str_buf,canon_path_len+1+name_len+1)))
+                HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+            HDstrcpy(new_canon_path, loc_canon_path);
+            HDstrcat(new_canon_path, "/");
+        } /* end else */
+
+        /* Append the component's name */
+        HDstrcat(new_canon_path, name);
+
+        /* Give ownership of the canonical path to the entry */
+        obj->canon_path_r=H5RS_own(new_canon_path);
+        assert(obj->canon_path_r);
+    } /* end if */
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5G_ent_set_name() */
+
 
 /*-------------------------------------------------------------------------
  * Function:    H5G_ent_debug
@@ -444,7 +600,7 @@ H5G_ent_debug(H5F_t UNUSED *f, hid_t dxpl_id, const H5G_entry_t *ent, FILE * str
 {
     const char		*lval = NULL;
     int nested_indent, nested_fwidth;
-    
+
     FUNC_ENTER_NOAPI_NOFUNC(H5G_ent_debug);
 
     /* Calculate the indent & field width values for nested information */
@@ -482,8 +638,8 @@ H5G_ent_debug(H5F_t UNUSED *f, hid_t dxpl_id, const H5G_entry_t *ent, FILE * str
 
         case H5G_CACHED_SLINK:
             HDfprintf (stream, "Symbolic Link\n");
-            HDfprintf(stream, "%*s%-*s ", indent, "", fwidth,
-                      "Cached information:\n");
+            HDfprintf(stream, "%*s%-*s\n", indent, "", fwidth,
+                      "Cached information:");
             HDfprintf (stream, "%*s%-*s %lu\n", nested_indent, "", nested_fwidth,
                        "Link value offset:",
                        (unsigned long)(ent->cache.slink.lval_offset));
@@ -500,7 +656,7 @@ H5G_ent_debug(H5F_t UNUSED *f, hid_t dxpl_id, const H5G_entry_t *ent, FILE * str
             else
                 HDfprintf(stream, "%*s%-*s\n", nested_indent, "", nested_fwidth, "Warning: Invalid heap address given, name not displayed!");
             break;
-            
+
         default:
             HDfprintf(stream, "*** Unknown symbol type %d\n", ent->type);
             break;
