@@ -65,7 +65,7 @@ NAME
    H5S_init_interface -- Initialize interface-specific information
 USAGE
     herr_t H5S_init_interface()
-   
+
 RETURNS
     Non-negative on success/Negative on failure
 DESCRIPTION
@@ -175,8 +175,8 @@ H5S_term_interface(void)
 				      "%10s\n", "gather",
 				      path->stats[j].gath_nbytes,
 				      path->stats[j].gath_ncalls,
-				      path->stats[j].gath_timer.utime, 
-				      path->stats[j].gath_timer.stime, 
+				      path->stats[j].gath_timer.utime,
+				      path->stats[j].gath_timer.stime,
 				      path->stats[j].gath_timer.etime,
 				      buf);
 			}
@@ -191,8 +191,8 @@ H5S_term_interface(void)
 				      "%10s\n", "scatter",
 				      path->stats[j].scat_nbytes,
 				      path->stats[j].scat_ncalls,
-				      path->stats[j].scat_timer.utime, 
-				      path->stats[j].scat_timer.stime, 
+				      path->stats[j].scat_timer.utime,
+				      path->stats[j].scat_timer.stime,
 				      path->stats[j].scat_timer.etime,
 				      buf);
 			}
@@ -207,8 +207,8 @@ H5S_term_interface(void)
 				      "%10s\n", "background",
 				      path->stats[j].bkg_nbytes,
 				      path->stats[j].bkg_ncalls,
-				      path->stats[j].bkg_timer.utime, 
-				      path->stats[j].bkg_timer.stime, 
+				      path->stats[j].bkg_timer.utime,
+				      path->stats[j].bkg_timer.stime,
 				      path->stats[j].bkg_timer.etime,
 				      buf);
 			}
@@ -228,7 +228,7 @@ H5S_term_interface(void)
 				      path->stats[j].read_timer.etime,
 				      buf);
 			}
-			
+
 			/* Write */
 			if (path->stats[j].write_ncalls) {
 			    H5_bandwidth(buf,
@@ -265,7 +265,7 @@ H5S_term_interface(void)
 	    n = 1; /*H5I*/
 	}
     }
-    
+
     FUNC_LEAVE_NOAPI(n);
 }
 
@@ -506,7 +506,7 @@ H5Scopy(hid_t space_id)
     H5S_t	*src = NULL;
     H5S_t	*dst = NULL;
     hid_t	ret_value;
-    
+
     FUNC_ENTER_API(H5Scopy, FAIL);
     H5TRACE1("i","i",space_id);
 
@@ -552,7 +552,7 @@ H5Sextent_copy(hid_t dst_id,hid_t src_id)
     H5S_t	*src = NULL;
     H5S_t	*dst = NULL;
     hid_t	ret_value = SUCCEED;
-    
+
     FUNC_ENTER_API(H5Sextent_copy, FAIL);
     H5TRACE2("e","ii",dst_id,src_id);
 
@@ -1125,7 +1125,7 @@ done:
  *-------------------------------------------------------------------------
  */
 H5S_t *
-H5S_read(H5G_entry_t *ent, hid_t dxpl_id)
+H5S_read(const H5G_entry_t *ent, hid_t dxpl_id)
 {
     H5S_t		   *ds = NULL;          /* Dataspace to return */
     H5S_t		   *ret_value;   /* Return value */
@@ -1375,7 +1375,7 @@ done:
  * Purpose:	Given two data spaces (MEM_SPACE and FILE_SPACE) this
  *		function returns a pointer to the conversion path information,
  *		creating a new conversion path entry if necessary.
- *		
+ *
  * Return:	Success:	Ptr to a conversion path entry
  *
  *		Failure:	NULL
@@ -1398,7 +1398,7 @@ done:
  *	statistics).
  *
  *	John Mainzer, 8/30/04
- *	Modified code to check with all other processes that have the 
+ *	Modified code to check with all other processes that have the
  *	file open before OKing collective I/O.
  *
  *-------------------------------------------------------------------------
@@ -1409,7 +1409,7 @@ H5S_find (const H5S_t *mem_space, const H5S_t *file_space)
     H5S_iostats_t	*path=NULL;  /* Space conversion path */
     size_t	u;      /* Index variable */
     H5S_iostats_t *ret_value;   /* Return value */
-    
+
     FUNC_ENTER_NOAPI(H5S_find, NULL);
 
     /* Check args */
@@ -1426,7 +1426,7 @@ H5S_find (const H5S_t *mem_space, const H5S_t *file_space)
         if (H5S_iostats_g[u]->ftype==H5S_GET_SELECT_TYPE(file_space) &&
                 H5S_iostats_g[u]->mtype==H5S_GET_SELECT_TYPE(mem_space))
             HGOTO_DONE(H5S_iostats_g[u]);
-    
+
     /*
      * The path wasn't found.  Create a new path.
      */
@@ -1486,7 +1486,7 @@ H5S_extend (H5S_t *space, const hsize_t *size)
 {
     int	ret_value=0;
     unsigned	u;
-    
+
     FUNC_ENTER_NOAPI(H5S_extend, FAIL);
 
     /* Check args */
@@ -1588,11 +1588,11 @@ H5Screate_simple(int rank, const hsize_t dims[/*rank*/],
     /* Create the space and set the extent */
     if(NULL==(space=H5S_create_simple((unsigned)rank,dims,maxdims)))
         HGOTO_ERROR (H5E_DATASPACE, H5E_CANTCREATE, FAIL, "can't create simple dataspace");
-    
+
     /* Atomize */
     if ((ret_value=H5I_register (H5I_DATASPACE, space))<0)
         HGOTO_ERROR (H5E_ATOM, H5E_CANTREGISTER, FAIL, "unable to register dataspace ID");
-    
+
 done:
     if (ret_value<0) {
         if (space!=NULL)
@@ -1638,7 +1638,7 @@ H5S_create_simple(unsigned rank, const hsize_t dims[/*rank*/],
         HGOTO_ERROR (H5E_DATASPACE, H5E_CANTCREATE, NULL, "can't create simple dataspace");
     if(H5S_set_extent_simple(ret_value,rank,dims,maxdims)<0)
         HGOTO_ERROR (H5E_DATASPACE, H5E_CANTINIT, NULL, "can't set dimensions");
-    
+
 done:
     FUNC_LEAVE_NOAPI(ret_value);
 } /* end H5S_create_simple() */
@@ -1707,7 +1707,7 @@ H5S_get_simple_extent_type(const H5S_t *space)
     assert(space);
 
     ret_value=H5S_GET_EXTENT_TYPE(space);
-    
+
 done:
     FUNC_LEAVE_NOAPI(ret_value);
 }
@@ -1745,7 +1745,7 @@ H5Sget_simple_extent_type(hid_t sid)
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5S_NO_CLASS, "not a dataspace");
 
     ret_value=H5S_GET_EXTENT_TYPE(space);
-    
+
 done:
     FUNC_LEAVE_API(ret_value);
 }
@@ -1851,7 +1851,7 @@ H5S_set_extent( H5S_t *space, const hsize_t *size )
 {
     unsigned u;
     herr_t ret_value=0;
-       
+
     FUNC_ENTER_NOAPI( H5S_set_extent, FAIL );
 
     /* Check args */
@@ -1928,7 +1928,7 @@ H5S_set_extent_real( H5S_t *space, const hsize_t *size )
     hsize_t nelem;      /* Number of elements in extent */
     unsigned u;         /* Local index variable */
     herr_t ret_value=SUCCEED;   /* Return value */
-       
+
     FUNC_ENTER_NOAPI(H5S_set_extent_real, FAIL );
 
     /* Check args */
@@ -1971,22 +1971,22 @@ H5S_debug(H5F_t *f, hid_t dxpl_id, const void *_mesg, FILE *stream, int indent,
 {
     const H5S_t	*mesg = (const H5S_t*)_mesg;
     herr_t ret_value=SUCCEED;   /* Return value */
-    
+
     FUNC_ENTER_NOAPI(H5S_debug, FAIL);
-    
+
     switch (H5S_GET_EXTENT_TYPE(mesg)) {
         case H5S_SCALAR:
             fprintf(stream, "%*s%-*s H5S_SCALAR\n", indent, "", fwidth,
                     "Space class:");
             break;
-            
+
         case H5S_SIMPLE:
             fprintf(stream, "%*s%-*s H5S_SIMPLE\n", indent, "", fwidth,
                     "Space class:");
             H5O_debug_id(H5O_SDSPACE_ID, f, dxpl_id, &(mesg->extent), stream,
                                  indent+3, MAX(0, fwidth-3));
             break;
-            
+
         default:
             fprintf(stream, "%*s%-*s **UNKNOWN-%ld**\n", indent, "", fwidth,
                     "Space class:", (long)(H5S_GET_EXTENT_TYPE(mesg)));
