@@ -46,7 +46,7 @@ NAME
    H5T_init_enum_interface -- Initialize interface-specific information
 USAGE
     herr_t H5T_init_enum_interface()
-   
+
 RETURNS
     Non-negative on success/Negative on failure
 DESCRIPTION
@@ -86,7 +86,7 @@ H5Tenum_create(hid_t parent_id)
     H5T_t	*parent = NULL;		/*base integer data type	*/
     H5T_t	*dt = NULL;		/*new enumeration data type	*/
     hid_t	ret_value;	        /*return value			*/
-    
+
     FUNC_ENTER_API(H5Tenum_create, FAIL)
     H5TRACE1("i","i",parent_id);
 
@@ -109,16 +109,16 @@ done:
 /*-------------------------------------------------------------------------
  * Function:	H5T_enum_create
  *
- * Purpose:	Private function for H5Tenum_create.  Create a new 
+ * Purpose:	Private function for H5Tenum_create.  Create a new
  *              enumeration data type based on the specified
  *		TYPE, which must be an integer type.
  *
  * Return:	Success:	new enumeration data type
  *
- *		Failure:        NULL	
+ *		Failure:        NULL
  *
  * Programmer:	Raymond Lu
- *              October 9, 2002 
+ *              October 9, 2002
  *
  * Modifications:
  *
@@ -128,23 +128,18 @@ H5T_t *
 H5T_enum_create(const H5T_t *parent)
 {
     H5T_t	*ret_value;		/*new enumeration data type	*/
-    
+
     FUNC_ENTER_NOAPI(H5T_enum_create, NULL)
 
     assert(parent);
 
     /* Build new type */
-    if (NULL==(ret_value = H5FL_CALLOC(H5T_t)))
+    if(NULL == (ret_value = H5T_alloc()))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
-    if (NULL==(ret_value->shared=H5FL_CALLOC(H5T_shared_t))) {
-        H5FL_FREE(H5T_t, ret_value);
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
-    }
     ret_value->shared->type = H5T_ENUM;
     ret_value->shared->parent = H5T_copy(parent, H5T_COPY_ALL);
     assert(ret_value->shared->parent);
     ret_value->shared->size = ret_value->shared->parent->shared->size;
-    ret_value->ent.header = HADDR_UNDEF;
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -177,7 +172,7 @@ H5Tenum_insert(hid_t type, const char *name, const void *value)
 {
     H5T_t	*dt=NULL;
     herr_t      ret_value=SUCCEED;       /* Return value */
-    
+
     FUNC_ENTER_API(H5Tenum_insert, FAIL)
     H5TRACE3("e","isx",type,name,value);
 
@@ -226,7 +221,7 @@ H5T_enum_insert(const H5T_t *dt, const char *name, const void *value)
     char	**names=NULL;
     uint8_t	*values=NULL;
     herr_t      ret_value=SUCCEED;       /* Return value */
-    
+
     FUNC_ENTER_NOAPI(H5T_enum_insert, FAIL)
 
     assert(dt);
@@ -287,7 +282,7 @@ H5Tget_member_value(hid_t type, unsigned membno, void *value/*out*/)
 {
     H5T_t	*dt=NULL;
     herr_t      ret_value=SUCCEED;       /* Return value */
-    
+
     FUNC_ENTER_API(H5Tget_member_value, FAIL)
     H5TRACE3("e","iIux",type,membno,value);
 
@@ -310,7 +305,7 @@ done:
 /*-------------------------------------------------------------------------
  * Function:	H5T_get_member_value
  *
- * Purpose:	Private function for H5T_get_member_value.  Return the 
+ * Purpose:	Private function for H5T_get_member_value.  Return the
  *              value for an enumeration data type member.
  *
  * Return:	Success:	non-negative with the member value copied
@@ -319,7 +314,7 @@ done:
  *		Failure:	negative, VALUE memory is undefined.
  *
  * Programmer:	Raymond Lu
- *              October 9, 2002 
+ *              October 9, 2002
  *
  * Modifications:
  *
@@ -329,7 +324,7 @@ herr_t
 H5T_get_member_value(const H5T_t *dt, unsigned membno, void *value/*out*/)
 {
     herr_t      ret_value=SUCCEED;       /* Return value */
-    
+
     FUNC_ENTER_NOAPI(H5T_get_member_value, FAIL)
 
     assert(dt);
@@ -424,10 +419,10 @@ static char *
 H5T_enum_nameof(const H5T_t *dt, const void *value, char *name/*out*/, size_t size)
 {
     unsigned	lt, md=0, rt;		/*indices for binary search	*/
-    int	        cmp=(-1);		/*comparison result		*/
+    int	cmp=(-1);		        /*comparison result		*/
     H5T_t       *copied_dt = NULL;      /*do sorting in copied datatype */
-    char        *ret_value;             /* Return value                 */
-    
+    char *ret_value;                    /* Return value */
+
     FUNC_ENTER_NOAPI(H5T_enum_nameof, NULL)
 
     /* Check args */
@@ -446,6 +441,7 @@ H5T_enum_nameof(const H5T_t *dt, const void *value, char *name/*out*/, size_t si
 	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, NULL, "unable to copy data type");
     if(H5T_sort_value(copied_dt, NULL)<0)
         HGOTO_ERROR(H5E_INTERNAL, H5E_CANTCOMPARE, NULL, "value sort failed")
+
     lt = 0;
     rt = copied_dt->shared->u.enumer.nmembs;
 
@@ -498,7 +494,10 @@ done:
  *              Monday, January  4, 1999
  *
  * Modifications:
- *
+ *              Raymond Lu
+ *              Wednesday, Febuary 9, 2005
+ *              Made a copy of original datatype and do sorting and search
+ *              on that copy, to protect the original order of members.
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -554,10 +553,10 @@ static herr_t
 H5T_enum_valueof(const H5T_t *dt, const char *name, void *value/*out*/)
 {
     unsigned	lt, md=0, rt;		/*indices for binary search	*/
-    int	        cmp=(-1);		/*comparison result		*/
+    int	cmp=(-1);		        /*comparison result		*/
     H5T_t       *copied_dt = NULL;      /*do sorting in copied datatype */
     herr_t      ret_value=SUCCEED;      /* Return value */
-    
+
     FUNC_ENTER_NOAPI(H5T_enum_valueof, FAIL)
 
     /* Check args */
@@ -575,6 +574,7 @@ H5T_enum_valueof(const H5T_t *dt, const char *name, void *value/*out*/)
 	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to copy data type");
     if(H5T_sort_name(copied_dt, NULL)<0)
         HGOTO_ERROR(H5E_INTERNAL, H5E_CANTCOMPARE, FAIL, "value sort failed")
+
     lt = 0;
     rt = copied_dt->shared->u.enumer.nmembs;
 
