@@ -97,6 +97,8 @@ in the file file_io.win32.c and including it on the projects
 /* comment the following two lines out if you are not using szip filter*/
 #define H5_HAVE_SZLIB_H 1
 #define H5_HAVE_FILTER_SZIP 1
+/* comment the following line out if your szlib library does not have an encoder */
+#define H5_SZIP_CAN_ENCODE 1
 
 
 #if defined(__MWERKS__) || defined(__cplusplus)
