@@ -29,6 +29,8 @@ const char *FILENAME[] = {
 #define WRT_SIZE	4*1024
 #define FAMILY_SIZE	1024*1024*1024
 
+#define MAX_TRIES       100
+
 #if H5_SIZEOF_LONG_LONG >= 8
 #   define GB8LL	((unsigned long_long)8*1024*1024*1024)
 #else
@@ -38,6 +40,7 @@ const char *FILENAME[] = {
 /* Protocols */
 static void usage(void);
 
+static hsize_t values_used[WRT_N];
 
 /*-------------------------------------------------------------------------
  * Function:	randll
@@ -56,13 +59,36 @@ static void usage(void);
  *-------------------------------------------------------------------------
  */
 static hsize_t
-randll(hsize_t limit)
+randll(hsize_t limit, int current_index)
 {
-    
-    hsize_t	acc = rand ();
-    acc *= rand ();
+    hsize_t     acc;
+    int         overlap = 1;
+    int         i;
+    int         tries = 0;
 
-    return acc % limit;
+    /* Generate up to MAX_TRIES random numbers until one of them */
+    /* does not overlap with any previous writes */
+    while(overlap != 0 && tries < MAX_TRIES)
+    {
+        acc = rand ();
+        acc *= rand ();
+        acc = acc % limit;
+        overlap = 0;
+
+        for(i = 0; i < current_index; i++)
+        {
+            if((acc >= values_used[i]) && (acc < values_used[i]+WRT_SIZE))
+                overlap = 1;
+            if((acc+WRT_SIZE >= values_used[i]) && (acc+WRT_SIZE < values_used[i
+]+WRT_SIZE))
+                overlap = 1;
+        }
+        tries++;
+    }
+
+    values_used[current_index]=acc;
+
+    return acc;
 }
 
 
@@ -89,7 +115,7 @@ is_sparse(void)
 {
     int		fd;
     h5_stat_t	sb;
-    
+
     if ((fd=HDopen("x.h5", O_RDWR|O_TRUNC|O_CREAT, 0666))<0) return 0;
     if (HDlseek(fd, (off_t)(1024*1024), SEEK_SET)!=1024*1024) return 0;
     if (5!=HDwrite(fd, "hello", 5)) return 0;
@@ -159,7 +185,7 @@ enough_room(hid_t fapl)
             ret_value=0;
 	HDunlink(name);
     }
-    
+
     return ret_value;
 }
 
@@ -197,7 +223,7 @@ writer (hid_t fapl, int wrt_n)
     hid_t       dcpl;
 
     TESTING("large dataset write");
-    
+
     /*
      * We might be on a machine that has 32-bit files, so create an HDF5 file
      * which is a family of files.  Each member of the family will be 1GB
@@ -206,15 +232,15 @@ writer (hid_t fapl, int wrt_n)
     if ((file=H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl))<0) {
 	goto error;
     }
-    
+
     /* Create simple data spaces according to the size specified above. */
     if ((space1 = H5Screate_simple (4, size1, size1))<0 ||
 	(space2 = H5Screate_simple (1, size2, size2))<0) {
 	goto error;
     }
-    
+
     /* Create the datasets */
-/* 
+/*
  *  The fix below is provided for bug#921
  *  H5Dcreate with H5P_DEFAULT creation properties
  *  will create a set of solid 1GB files; test will crash if quotas are enforced
@@ -234,13 +260,13 @@ writer (hid_t fapl, int wrt_n)
 	(d2=H5Dcreate (file, "d2", H5T_NATIVE_INT, space2, dcpl))<0) {
 	goto error;
     }
-    
+
 
     /* Write some things to them randomly */
     hs_size[0] = WRT_SIZE;
     if ((mem_space = H5Screate_simple (1, hs_size, hs_size))<0) goto error;
     for (i=0; i<wrt_n; i++) {
-	hs_start[0] = randll (size2[0]);
+	hs_start[0] = randll (size2[0], i);
 	HDfprintf (out, "#%03d 0x%016Hx\n", i, hs_start[0]);
 	if (H5Sselect_hyperslab (space2, H5S_SELECT_SET, hs_start, NULL,
 				 hs_size, NULL)<0) goto error;
@@ -250,7 +276,7 @@ writer (hid_t fapl, int wrt_n)
 	if (H5Dwrite (d2, H5T_NATIVE_INT, mem_space, space2,
 		      H5P_DEFAULT, buf)<0) goto error;
     }
-	
+
     if (H5Dclose (d1)<0) goto error;
     if (H5Dclose (d2)<0) goto error;
     if (H5Sclose (mem_space)<0) goto error;
@@ -408,11 +434,11 @@ usage(void)
 /*-------------------------------------------------------------------------
  * Function:	main
  *
- * Purpose:	
+ * Purpose:
  *
- * Return:	Success:	
+ * Return:	Success:
  *
- *		Failure:	
+ *		Failure:
  *
  * Programmer:	Robb Matzke
  *              Friday, April 10, 1998
@@ -433,7 +459,7 @@ main (int ac, char **av)
     hsize_t	family_size_def;	/* default family file size */
     double	family_size_def_dbl;	/* default family file size */
     int		cflag=1;		/* check file system before test */
-    
+
     /* parameters setup */
     family_size_def = FAMILY_SIZE;
 
@@ -515,7 +541,7 @@ main (int ac, char **av)
 	    goto quit;
 	}
     }
-    
+
     /* Do the test */
     if (writer(fapl, WRT_N)) goto error;
     if (reader(fapl)) goto error;
