@@ -41,7 +41,7 @@
 #define F2_RANK            2
 #define F2_DIM0            4
 #define F2_DIM1            6
-#define F2_DSET            "dset"                                                
+#define F2_DSET            "dset"
 #define FILE2	"tfile2.h5"
 
 #define F3_USERBLOCK_SIZE  (hsize_t)0
@@ -58,26 +58,39 @@
 #define FILE4	           "tfile4.h5"
 
 #define OBJ_ID_COUNT_0     0
-#define OBJ_ID_COUNT_1     1 
+#define OBJ_ID_COUNT_1     1
 #define OBJ_ID_COUNT_2     2
-#define OBJ_ID_COUNT_3     3 
-#define OBJ_ID_COUNT_4     4 
-#define OBJ_ID_COUNT_6	   6    
-#define OBJ_ID_COUNT_8     8 
+#define OBJ_ID_COUNT_3     3
+#define OBJ_ID_COUNT_4     4
+#define OBJ_ID_COUNT_6	   6
+#define OBJ_ID_COUNT_8     8
+
+#define GROUP1  "Group1"
+#define DSET1   "Dataset1"
+#define DSET2   "/Group1/Dataset2"
+
+#define TESTA_GROUPNAME "group"
+#define TESTA_DSETNAME "dataset"
+#define TESTA_ATTRNAME "attribute"
+#define TESTA_DTYPENAME "compound"
+#define TESTA_NAME_BUF_SIZE     64
+#define TESTA_RANK 2
+#define TESTA_NX 4
+#define TESTA_NY 5
 
 static void
 create_objects(hid_t, hid_t, hid_t *, hid_t *, hid_t *, hid_t *);
 static void
 test_obj_count_and_id(hid_t, hid_t, hid_t, hid_t, hid_t, hid_t);
-static void 
+static void
 check_file_id(hid_t, hid_t);
 
 /****************************************************************
 **
 **  test_file_create(): Low-level file creation I/O test routine.
-** 
+**
 ****************************************************************/
-static void 
+static void
 test_file_create(void)
 {
     hid_t		fid1, fid2, fid3; /* HDF5 File IDs		*/
@@ -180,7 +193,7 @@ test_file_create(void)
     ret = H5Pset_userblock(tmpl1, F2_USERBLOCK_SIZE);
     CHECK(ret, FAIL, "H5Pset_userblock");
 
-    ret = H5Pset_sizes(tmpl1, F2_OFFSET_SIZE, F2_LENGTH_SIZE);
+    ret = H5Pset_sizes(tmpl1, (size_t)F2_OFFSET_SIZE, (size_t)F2_LENGTH_SIZE);
     CHECK(ret, FAIL, "H5Pset_sizes");
 
     ret = H5Pset_sym_k(tmpl1, F2_SYM_INTERN_K, F2_SYM_LEAF_K);
@@ -205,8 +218,8 @@ test_file_create(void)
        unsigned i,j;
 
        /* Create the data space for the dataset. */
-       dims[0] = F2_DIM0; 
-       dims[1] = F2_DIM1; 
+       dims[0] = F2_DIM0;
+       dims[1] = F2_DIM1;
        dataspace_id = H5Screate_simple(F2_RANK, dims, NULL);
        CHECK(dataspace_id, FAIL, "H5Screate_simple");
 
@@ -226,7 +239,7 @@ test_file_create(void)
        ret = H5Dclose(dataset_id);
        CHECK(ret, FAIL, "H5Dclose");
 
-       /* Terminate access to the data space. */ 
+       /* Terminate access to the data space. */
        ret = H5Sclose(dataspace_id);
        CHECK(ret, FAIL, "H5Sclose");
     }
@@ -312,9 +325,9 @@ test_file_create(void)
 /****************************************************************
 **
 **  test_file_open(): Low-level file open I/O test routine.
-** 
+**
 ****************************************************************/
-static void 
+static void
 test_file_open(void)
 {
     hid_t		fid1, fid2;     /*HDF5 File IDs			*/
@@ -333,9 +346,9 @@ test_file_open(void)
     herr_t		ret;		/*generic return value		*/
 
     /*
-     * Test single file open 
+     * Test single file open
      */
-     
+
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Low-Level File Opening I/O\n"));
 
@@ -372,8 +385,8 @@ test_file_open(void)
 
 
     /*
-     * Test two file opens: one is opened H5F_ACC_RDONLY and H5F_CLOSE_WEAK.  
-     * It's closed with an object left open.  Then another is opened 
+     * Test two file opens: one is opened H5F_ACC_RDONLY and H5F_CLOSE_WEAK.
+     * It's closed with an object left open.  Then another is opened
      * H5F_ACC_RDWR, which should fail.
      */
 
@@ -383,7 +396,7 @@ test_file_open(void)
     /* Create file access property list */
     fapl_id = H5Pcreate(H5P_FILE_ACCESS);
     CHECK(fapl_id, FAIL, "H5Pcreate");
-    
+
     /* Set file close mode to H5F_CLOSE_WEAK */
     ret = H5Pset_fclose_degree(fapl_id, H5F_CLOSE_WEAK);
     CHECK(ret, FAIL, "H5Pset_fclose_degree");
@@ -391,7 +404,7 @@ test_file_open(void)
     /* Open file for first time */
     fid1 = H5Fopen(FILE2, H5F_ACC_RDONLY, fapl_id);
     CHECK(fid1, FAIL, "H5Fopen");
-    
+
     /* Open dataset */
     did = H5Dopen(fid1, F2_DSET);
     CHECK(did, FAIL, "H5Dopen");
@@ -411,11 +424,11 @@ test_file_open(void)
 
 /****************************************************************
 **
-**  test_file_close():  low-level file close test routine.  
+**  test_file_close():  low-level file close test routine.
 **                      It mainly tests behavior with close degree.
 **
 *****************************************************************/
-static void 
+static void
 test_file_close(void)
 {
     hid_t               fid1, fid2;
@@ -429,7 +442,7 @@ test_file_close(void)
      */
     fid1 = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid1, FAIL, "H5Fcreate");
- 
+
     fapl_id = H5Pcreate(H5P_FILE_ACCESS);
     CHECK(fapl_id, FAIL, "H5Pcreate");
 
@@ -445,8 +458,8 @@ test_file_close(void)
 
     ret = H5Pset_fclose_degree(fapl_id, H5F_CLOSE_DEFAULT);
     CHECK(ret, FAIL, "H5Pset_fclose_degree");
-   
-    /* should succeed */ 
+
+    /* should succeed */
     fid2 = H5Fopen(FILE1, H5F_ACC_RDWR, fapl_id);
     CHECK(fid2, FAIL, "H5Fopen");
 
@@ -459,7 +472,7 @@ test_file_close(void)
     CHECK(ret, FAIL, "H5Fclose");
 
 
-    /* Test behavior while opening file multiple times with different file 
+    /* Test behavior while opening file multiple times with different file
      * close degree
      */
     fid1 = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
@@ -484,7 +497,7 @@ test_file_close(void)
     CHECK(ret, FAIL, "H5Fclose");
 
 
-    /* Test behavior while opening file multiple times with file close 
+    /* Test behavior while opening file multiple times with file close
      * degree STRONG */
     ret = H5Pset_fclose_degree(fapl_id, H5F_CLOSE_STRONG);
     CHECK(ret, FAIL, "H5Pset_fclose_degree");
@@ -543,29 +556,38 @@ test_file_close(void)
     /* Create a dataset and a group in each file open respectively */
     create_objects(fid1, fid2, &dataset_id, &group_id1, &group_id2, &group_id3);
 
-    /* Close first open */
+    /* Close first open, should fail since it is SEMI and objects are
+     * still open. */
     ret = H5Fclose(fid1);
-    CHECK(ret, FAIL, "H5Fclose");
+    VERIFY(ret, FAIL, "H5Fclose");
 
-    /* Close second open, should fail since it is SEMI and objects are 
+    /* Close second open, should fail since it is SEMI and objects are
      * still open. */
     ret = H5Fclose(fid2);
     VERIFY(ret, FAIL, "H5Fclose");
 
     ret = H5Dclose(dataset_id);
     CHECK(ret, FAIL, "H5Dclose");
-  
+
+    /* Close first open */
+    ret = H5Fclose(fid1);
+    CHECK(ret, FAIL, "H5Fclose");
+
     ret = H5Gclose(group_id1);
     CHECK(ret, FAIL, "H5Gclose");
 
     ret = H5Gclose(group_id2);
     CHECK(ret, FAIL, "H5Gclose");
 
-    /* Close second open, should fail since it is SEMI and one group ID is 
+    /* Close second open, should fail since it is SEMI and one group ID is
      * still open. */
     ret = H5Fclose(fid2);
     VERIFY(ret, FAIL, "H5Fclose");
 
+    /* Same check with H5Idec_ref() (should fail also) */
+    ret = H5Idec_ref(fid2);
+    VERIFY(ret, FAIL, "H5Idec_ref");
+
     ret = H5Gclose(group_id3);
     CHECK(ret, FAIL, "H5Gclose");
 
@@ -600,14 +622,14 @@ test_file_close(void)
     create_objects(fid1, fid2, &dataset_id, &group_id1, &group_id2, &group_id3);
 
     /* Create more new files and test object count and ID list functions */
-    test_obj_count_and_id(fid1, fid2, dataset_id, group_id1, 
+    test_obj_count_and_id(fid1, fid2, dataset_id, group_id1,
 				group_id2, group_id3);
- 
+
     /* Close first open */
     ret = H5Fclose(fid1);
     CHECK(ret, FAIL, "H5Fclose");
 
-    /* Close second open.  File will be finally closed after all objects 
+    /* Close second open.  File will be finally closed after all objects
      * are closed. */
     ret = H5Fclose(fid2);
     CHECK(ret, FAIL, "H5Fclose");
@@ -649,7 +671,7 @@ test_file_close(void)
 
     /* Create a dataset and a group in each file open respectively */
     create_objects(fid1, fid2, &dataset_id, &group_id1, &group_id2, &group_id3);
-    
+
     access_id = H5Fget_access_plist(fid1);
     CHECK(access_id, FAIL, "H5Fget_access_plist");
 
@@ -716,7 +738,7 @@ test_file_close(void)
 **
 ****************************************************************/
 static void
-create_objects(hid_t fid1, hid_t fid2, hid_t *ret_did, hid_t *ret_gid1, 
+create_objects(hid_t fid1, hid_t fid2, hid_t *ret_did, hid_t *ret_gid1,
 		hid_t *ret_gid2, hid_t *ret_gid3)
 {
     int	oid_count;
@@ -782,7 +804,7 @@ create_objects(hid_t fid1, hid_t fid2, hid_t *ret_did, hid_t *ret_gid1,
     /* Create a group in the second file open */
     {
         hid_t   gid1, gid2, gid3;
-        gid1 = H5Gcreate(fid2, "/group", 0);
+        gid1 = H5Gcreate(fid2, "/group", (size_t)0);
         CHECK(gid1, FAIL, "H5Gcreate");
         if(ret_gid1 != NULL)
             *ret_gid1 = gid1;
@@ -823,10 +845,10 @@ create_objects(hid_t fid1, hid_t fid2, hid_t *ret_did, hid_t *ret_gid1,
 
 /****************************************************************
 **
-**  test_get_file_id(): Test H5Iget_file_id() 
+**  test_get_file_id(): Test H5Iget_file_id()
 **
 *****************************************************************/
-static void 
+static void
 test_get_file_id(void)
 {
     hid_t               fid, fid2, fid3;
@@ -845,9 +867,9 @@ test_get_file_id(void)
     /* Create a group in the file.  Make a duplicated file ID from the group.
      * And close this duplicated ID
      */
-    group_id = H5Gcreate(fid, GRP_NAME, 0);
+    group_id = H5Gcreate(fid, GRP_NAME, (size_t)0);
     CHECK(group_id, FAIL, "H5Gcreate");
-   
+
     /* Test H5Iget_file_id() */
     check_file_id(fid, group_id);
 
@@ -860,29 +882,29 @@ test_get_file_id(void)
 
     ret = H5Gclose(group_id);
     CHECK(ret, FAIL, "H5Gclose");
-   
+
     /* Open the file again.  Test H5Iget_file_id() */
-    fid = H5Fopen(FILE4, H5F_ACC_RDWR, H5P_DEFAULT);       
+    fid = H5Fopen(FILE4, H5F_ACC_RDWR, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
-   
+
     group_id = H5Gopen(fid, GRP_NAME);
     CHECK(group_id, FAIL, "H5Gcreate");
-   
+
     /* Test H5Iget_file_id() */
     check_file_id(fid, group_id);
 
     /* Open the file for second time.  Test H5Iget_file_id() */
     fid3 = H5Freopen(fid);
     CHECK(fid3, FAIL, "H5Freopen");
-    
+
     /* Test H5Iget_file_id() */
     check_file_id(fid3, fid3);
-    
+
     ret = H5Fclose(fid3);
     CHECK(ret, FAIL, "H5Fclose");
-     
-    /* Create a dataset in the group.  Make a duplicated file ID from the 
-     * dataset.  And close this duplicated ID. 
+
+    /* Create a dataset in the group.  Make a duplicated file ID from the
+     * dataset.  And close this duplicated ID.
      */
     dims[0] = F2_DIM0;
     dims[1] = F2_DIM1;
@@ -892,10 +914,10 @@ test_get_file_id(void)
     dataset_id = H5Dcreate(group_id, DSET_NAME, H5T_NATIVE_INT, dataspace_id,
                         H5P_DEFAULT);
     CHECK(dataset_id, FAIL, "H5Dcreate");
-    
+
     /* Test H5Iget_file_id() */
     check_file_id(fid, dataset_id);
-    
+
     /* Create an attribute for the dataset.  Make a duplicated file ID from
      * this attribute.  And close it.
      */
@@ -910,10 +932,10 @@ test_get_file_id(void)
      */
     datatype_id=H5Tcopy(H5T_NATIVE_INT);
     CHECK(ret, FAIL, "H5Acreate");
-    
+
     ret = H5Tcommit(fid, TYPE_NAME, datatype_id);
     CHECK(ret, FAIL, "H5Tcommit");
-    
+
     /* Test H5Iget_file_id() */
     check_file_id(fid, datatype_id);
 
@@ -922,38 +944,38 @@ test_get_file_id(void)
      */
     plist = H5Pcreate(H5P_FILE_ACCESS);
     CHECK(plist, FAIL, "H5Pcreate");
-    
+
     H5E_BEGIN_TRY {
         fid2 = H5Iget_file_id(plist);
     } H5E_END_TRY;
     VERIFY(fid2, FAIL, "H5Iget_file_id");
-    
-    /* Close objects */ 
+
+    /* Close objects */
     ret = H5Tclose(datatype_id);
     CHECK(ret, FAIL, "H5Tclose");
 
     ret = H5Aclose(attr_id);
     CHECK(ret, FAIL, "H5Aclose");
-    
+
     ret = H5Sclose(dataspace_id);
     CHECK(ret, FAIL, "H5Sclose");
 
     ret = H5Dclose(dataset_id);
     CHECK(ret, FAIL, "H5Dclose");
-   
+
     ret = H5Gclose(group_id);
     CHECK(ret, FAIL, "H5Gclose");
-   
+
     ret = H5Fclose(fid);
     CHECK(ret, FAIL, "H5Fclose");
 }
 
 /****************************************************************
 **
-**  check_file_id(): Internal function of test_get_file_id() 
+**  check_file_id(): Internal function of test_get_file_id()
 **
 *****************************************************************/
-static void 
+static void
 check_file_id(hid_t fid, hid_t object_id)
 {
     hid_t               new_fid;
@@ -975,11 +997,11 @@ check_file_id(hid_t fid, hid_t object_id)
 
 /****************************************************************
 **
-**  test_obj_count_and_id(): test object count and ID list functions. 
+**  test_obj_count_and_id(): test object count and ID list functions.
 **
 ****************************************************************/
-static void 
-test_obj_count_and_id(hid_t fid1, hid_t fid2, hid_t did, hid_t gid1, 
+static void
+test_obj_count_and_id(hid_t fid1, hid_t fid2, hid_t did, hid_t gid1,
 			hid_t gid2, hid_t gid3)
 {
     hid_t    fid3, fid4;
@@ -1048,7 +1070,7 @@ test_obj_count_and_id(hid_t fid1, hid_t fid2, hid_t did, hid_t gid1,
                         oid_list[i]!=gid3) {
 			ret = FAIL;
                         CHECK(ret, FAIL, "H5Fget_obj_ids");
-                    }   
+                    }
 		    break;
 	        case H5I_DATASET:
 	 	    VERIFY(oid_list[i], did, "H5Fget_obj_ids");
@@ -1057,7 +1079,7 @@ test_obj_count_and_id(hid_t fid1, hid_t fid2, hid_t did, hid_t gid1,
 		    ret = FAIL;
                     CHECK(ret, FAIL, "H5Fget_obj_ids");
 	    }
-        }	
+        }
 
         free(oid_list);
     }
@@ -1071,13 +1093,13 @@ test_obj_count_and_id(hid_t fid1, hid_t fid2, hid_t did, hid_t gid1,
 
 /****************************************************************
 **
-**  test_file_perm(): low-level file test routine.  
-**      This test verifies that a file can be opened for both 
+**  test_file_perm(): low-level file test routine.
+**      This test verifies that a file can be opened for both
 **      read-only and read-write access and things will be handled
 **      appropriately.
 **
 *****************************************************************/
-static void 
+static void
 test_file_perm(void)
 {
     hid_t    file;      /* File opened with read-write permission */
@@ -1085,7 +1107,7 @@ test_file_perm(void)
     hid_t    dspace;    /* Dataspace ID */
     hid_t    dset;      /* Dataset ID */
     herr_t   ret;
- 
+
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Low-Level File Permissions\n"));
 
@@ -1130,12 +1152,12 @@ test_file_perm(void)
 
 /****************************************************************
 **
-**  test_file_freespace(): low-level file test routine.  
+**  test_file_freespace(): low-level file test routine.
 **      This test checks the free space available in a file in various
 **      situations.
 **
 *****************************************************************/
-static void 
+static void
 test_file_freespace(void)
 {
     hid_t    file;      /* File opened with read-write permission */
@@ -1146,7 +1168,7 @@ test_file_freespace(void)
     unsigned u;         /* Local index variable */
     char     name[32];  /* Dataset name */
     herr_t   ret;
- 
+
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Low-Level File Free Space\n"));
 
@@ -1165,11 +1187,11 @@ test_file_freespace(void)
 
     /* Create a dataset creation property list */
     dcpl = H5Pcreate(H5P_DATASET_CREATE);
-    CHECK(dcpl, FAIL, "H5Pcreate"); 
+    CHECK(dcpl, FAIL, "H5Pcreate");
 
     /* Set the space allocation time to early */
     ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_EARLY);
-    CHECK(ret, FAIL, "H5Pset_alloc_time"); 
+    CHECK(ret, FAIL, "H5Pset_alloc_time");
 
     /* Create datasets in file */
     for(u=0; u<10; u++) {
@@ -1222,12 +1244,12 @@ test_file_freespace(void)
 
 /****************************************************************
 **
-**  test_file_ishdf5(): low-level file test routine.  
+**  test_file_ishdf5(): low-level file test routine.
 **      This test checks whether the H5Fis_hdf5() routine is working
 **      correctly in variuous situations.
 **
 *****************************************************************/
-static void 
+static void
 test_file_ishdf5(void)
 {
     hid_t    file;      /* File opened with read-write permission */
@@ -1238,7 +1260,7 @@ test_file_ishdf5(void)
     unsigned char buf[1024];    /* Buffer of data to write */
     htri_t   status;    /* Whether a file is an HDF5 file */
     herr_t   ret;
- 
+
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Detection of HDF5 Files\n"));
 
@@ -1288,7 +1310,7 @@ test_file_ishdf5(void)
         buf[u]=(unsigned char)u;
 
     /* Write some information */
-    nbytes = HDwrite(fd, buf, 1024);
+    nbytes = HDwrite(fd, buf, (size_t)1024);
     VERIFY(nbytes, 1024, "HDwrite");
 
     /* Close the file */
@@ -1301,12 +1323,497 @@ test_file_ishdf5(void)
 
 } /* end test_file_ishdf5() */
 
+/****************************************************************
+**
+**  test_file_open_dot(): low-level file test routine.
+**      This test checks whether opening objects with "." for a name
+**      works correctly in variuous situations.
+**
+*****************************************************************/
+static void
+test_file_open_dot(void)
+{
+    hid_t fid;          /* File ID */
+    hid_t gid, gid2;    /* Group IDs */
+    hid_t did;          /* Dataset ID */
+    hid_t sid;          /* Dataspace ID */
+    hid_t tid, tid2;    /* Datatype IDs */
+    herr_t   ret;
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing opening objects with \".\" for a name\n"));
+
+    /* Create a new HDF5 file to work with */
+    fid = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(fid, FAIL, "H5Fcreate");
+
+    /* Create a group in the HDF5 file */
+    gid = H5Gcreate(fid, GRP_NAME, (size_t)0);
+    CHECK(gid, FAIL, "H5Gcreate");
+
+    /* Create a dataspace for creating datasets */
+    sid = H5Screate(H5S_SCALAR);
+    CHECK(sid, FAIL, "H5Screate");
+
+    /* Create a dataset with no name using the file ID */
+    H5E_BEGIN_TRY {
+        did = H5Dcreate(fid, ".", H5T_NATIVE_INT, sid, H5P_DEFAULT);
+    } H5E_END_TRY;
+    VERIFY(did, FAIL, "H5Dcreate");
+
+    /* Create a dataset with no name using the group ID */
+    H5E_BEGIN_TRY {
+        did = H5Dcreate(gid, ".", H5T_NATIVE_INT, sid, H5P_DEFAULT);
+    } H5E_END_TRY;
+    VERIFY(did, FAIL, "H5Dcreate");
+
+    /* Open a dataset with no name using the file ID */
+    H5E_BEGIN_TRY {
+        did = H5Dopen(fid, ".");
+    } H5E_END_TRY;
+    VERIFY(did, FAIL, "H5Dopen");
+
+    /* Open a dataset with no name using the group ID */
+    H5E_BEGIN_TRY {
+        did = H5Dopen(gid, ".");
+    } H5E_END_TRY;
+    VERIFY(did, FAIL, "H5Dopen");
+
+    /* Make a copy of a datatype to use for creating a named datatype */
+    tid = H5Tcopy(H5T_NATIVE_INT);
+    CHECK(tid, FAIL, "H5Tcopy");
+
+    /* Create a named datatype with no name using the file ID */
+    H5E_BEGIN_TRY {
+        ret = H5Tcommit(fid, ".", tid);
+    } H5E_END_TRY;
+    VERIFY(ret, FAIL, "H5Tcommit");
+
+    /* Create a named datatype with no name using the group ID */
+    H5E_BEGIN_TRY {
+        ret = H5Tcommit(gid, ".", tid);
+    } H5E_END_TRY;
+    VERIFY(ret, FAIL, "H5Tcommit");
+
+    /* Open a named datatype with no name using the file ID */
+    H5E_BEGIN_TRY {
+        tid2 = H5Topen(fid, ".");
+    } H5E_END_TRY;
+    VERIFY(tid2, FAIL, "H5Topen");
+
+    /* Open a named datatype with no name using the group ID */
+    H5E_BEGIN_TRY {
+        tid2 = H5Topen(gid, ".");
+    } H5E_END_TRY;
+    VERIFY(tid2, FAIL, "H5Topen");
+
+    /* Create a group with no name using the file ID */
+    H5E_BEGIN_TRY {
+        gid2 = H5Gcreate(fid, ".", (size_t)0);
+    } H5E_END_TRY;
+    VERIFY(gid2, FAIL, "H5Gcreate");
+
+    /* Create a group with no name using the group ID */
+    H5E_BEGIN_TRY {
+        gid2 = H5Gcreate(gid, ".", (size_t)0);
+    } H5E_END_TRY;
+    VERIFY(gid2, FAIL, "H5Gcreate");
+
+    /* Open a group with no name using the file ID (should open the root group) */
+    gid2 = H5Gopen(fid, ".");
+    CHECK(gid2, FAIL, "H5Gopen");
+
+    ret = H5Gclose(gid2);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    /* Open a group with no name using the group ID (should open the group again) */
+    gid2 = H5Gopen(gid, ".");
+    CHECK(gid2, FAIL, "H5Gopen");
+
+    ret = H5Gclose(gid2);
+    CHECK(ret, FAIL, "H5Gclose");
+
+
+    /* Close everything */
+    ret = H5Sclose(sid);
+    CHECK(ret, FAIL, "H5Sclose");
+
+    ret = H5Gclose(gid);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    ret = H5Fclose(fid);
+    CHECK(ret, FAIL, "H5Fclose");
+
+} /* end test_file_open_dot() */
+
+/****************************************************************
+**
+**  test_file_open_overlap(): low-level file test routine.
+**      This test checks whether opening files in an overlapping way
+**      (as opposed to a nested manner) works correctly.
+**
+*****************************************************************/
+static void
+test_file_open_overlap(void)
+{
+    hid_t fid1, fid2;
+    hid_t did1, did2;
+    hid_t gid;
+    hid_t sid;
+    int nobjs;          /* # of open objects */
+    herr_t ret;         /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing opening overlapping file opens\n"));
+
+    /* Create file */
+    fid1 = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(fid1, FAIL, "H5Fcreate");
+
+    /* Open file also */
+    fid2 = H5Fopen(FILE1, H5F_ACC_RDWR, H5P_DEFAULT);
+    CHECK(fid2, FAIL, "H5Fopen");
+
+    /* Create a group in file */
+    gid = H5Gcreate(fid1, GROUP1, (size_t)0);
+    CHECK(gid, FAIL, "H5Gcreate");
+
+    /* Create dataspace for dataset */
+    sid = H5Screate(H5S_SCALAR);
+    CHECK(sid, FAIL, "H5Screate");
+
+    /* Create dataset in group w/first file ID */
+    did1 = H5Dcreate(gid, DSET1, H5T_NATIVE_INT, sid, H5P_DEFAULT);
+    CHECK(did1, FAIL, "H5Dcreate");
+
+    /* Check number of objects opened in first file */
+    nobjs = H5Fget_obj_count(fid1, H5F_OBJ_LOCAL|H5F_OBJ_ALL);
+    VERIFY(nobjs, 3, "H5Fget_obj_count");       /* 3 == file, dataset & group */
+
+    /* Close dataset */
+    ret = H5Dclose(did1);
+    CHECK(ret, FAIL, "H5Dclose");
+
+    /* Close group */
+    ret = H5Gclose(gid);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    /* Close first file ID */
+    ret = H5Fclose(fid1);
+    CHECK(ret, FAIL, "H5Fclose");
+
+
+    /* Create dataset with second file ID */
+    did2 = H5Dcreate(fid2, DSET2, H5T_NATIVE_INT, sid, H5P_DEFAULT);
+    CHECK(did2, FAIL, "H5Dcreate");
+
+    /* Check number of objects opened in first file */
+    nobjs = H5Fget_obj_count(fid2, H5F_OBJ_ALL);
+    VERIFY(nobjs, 2, "H5Fget_obj_count");       /* 3 == file & dataset */
+
+    /* Close dataspace */
+    ret = H5Sclose(sid);
+    CHECK(ret, FAIL, "H5Sclose");
+
+    /* Close second dataset */
+    ret = H5Dclose(did2);
+    CHECK(ret, FAIL, "H5Dclose");
+
+    /* Close second file */
+    ret = H5Fclose(fid2);
+    CHECK(ret, FAIL, "H5Fclose");
+} /* end test_file_open_overlap() */
+
+/****************************************************************
+**
+**  test_file_getname(): low-level file test routine.
+**      This test checks whether H5Fget_name works correctly.
+**
+*****************************************************************/
+static void
+test_file_getname(void)
+{
+    /* Compound datatype */
+    typedef struct s1_t {
+        unsigned int a;
+        float        b;
+    } s1_t;
+
+    hid_t   file_id;
+    hid_t   group_id;
+    hid_t   dataset_id;
+    hid_t   space_id;
+    hid_t   type_id;
+    hid_t   attr_id;
+    hsize_t dims[TESTA_RANK] = {TESTA_NX, TESTA_NY};
+    char    name[TESTA_NAME_BUF_SIZE];
+    ssize_t name_len;
+    herr_t ret;         /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing H5Fget_name() functionality\n"));
+
+    /* Create a new file_id using default properties. */
+    file_id = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT );
+    CHECK(file_id, FAIL, "H5Fcreate");
+
+    /* Get and verify file name */
+    name_len = H5Fget_name(file_id, name, TESTA_NAME_BUF_SIZE);
+    CHECK(name_len, FAIL, "H5Fget_name");
+    VERIFY_STR(name, FILE1, "H5Fget_name");
+
+    /* Create a group in the root group */
+    group_id = H5Gcreate(file_id, TESTA_GROUPNAME, 0);
+    CHECK(group_id, FAIL, "H5Gcreate");
+
+    /* Get and verify file name */
+    name_len = H5Fget_name(group_id, name, TESTA_NAME_BUF_SIZE);
+    CHECK(name_len, FAIL, "H5Fget_name");
+    VERIFY_STR(name, FILE1, "H5Fget_name");
+
+    /* Create the data space  */
+    space_id = H5Screate_simple(TESTA_RANK, dims, NULL);
+    CHECK(space_id, FAIL, "H5Screate_simple");
+
+    /* Try get file name from data space.  Supposed to fail because
+     * it's illegal operation. */
+    H5E_BEGIN_TRY {
+        name_len = H5Fget_name(space_id, name, TESTA_NAME_BUF_SIZE);
+    } H5E_END_TRY;
+    VERIFY(name_len, FAIL, "H5Fget_name");
+
+    /* Create a new dataset */
+    dataset_id = H5Dcreate(file_id, TESTA_DSETNAME, H5T_NATIVE_INT, space_id, H5P_DEFAULT);
+    CHECK(dataset_id, FAIL, "H5Dcreate");
+
+    /* Get and verify file name */
+    name_len = H5Fget_name(dataset_id, name, TESTA_NAME_BUF_SIZE);
+    CHECK(name_len, FAIL, "H5Fget_name");
+    VERIFY_STR(name, FILE1, "H5Fget_name");
+
+    /* Create an attribute for the dataset */
+    attr_id = H5Acreate(dataset_id,TESTA_ATTRNAME,H5T_NATIVE_INT,space_id,H5P_DEFAULT);
+    CHECK(attr_id, FAIL, "H5Acreate");
+
+    /* Get and verify file name */
+    name_len = H5Fget_name(attr_id, name, TESTA_NAME_BUF_SIZE);
+    CHECK(name_len, FAIL, "H5Fget_name");
+    VERIFY_STR(name, FILE1, "H5Fget_name");
+
+    /* Create a compound datatype */
+    type_id = H5Tcreate(H5T_COMPOUND, sizeof(s1_t));
+    CHECK(type_id, FAIL, "H5Tcreate");
+
+    /* Insert fields */
+    ret = H5Tinsert (type_id, "a", HOFFSET(s1_t,a), H5T_NATIVE_INT);
+    CHECK(ret, FAIL, "H5Tinsert");
+
+    ret = H5Tinsert (type_id, "b", HOFFSET(s1_t,b), H5T_NATIVE_FLOAT);
+    CHECK(ret, FAIL, "H5Tinsert");
+
+    /* Save it on file */
+    ret = H5Tcommit(file_id, TESTA_DTYPENAME, type_id);
+    CHECK(ret, FAIL, "H5Tcommit");
+
+    /* Get and verify file name */
+    name_len = H5Fget_name(type_id, name, TESTA_NAME_BUF_SIZE);
+    CHECK(name_len, FAIL, "H5Fget_name");
+    VERIFY_STR(name, FILE1, "H5Fget_name");
+
+    /* Close things down */
+    ret = H5Tclose(type_id);
+    CHECK(ret, FAIL, "H5Tclose");
+
+    ret = H5Aclose(attr_id);
+    CHECK(ret, FAIL, "H5Aclose");
+
+    ret = H5Dclose(dataset_id);
+    CHECK(ret, FAIL, "H5Dclose");
+
+    ret = H5Sclose(space_id);
+    CHECK(ret, FAIL, "H5Sclose");
+
+    ret = H5Gclose(group_id);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    ret = H5Fclose(file_id);
+    CHECK(ret, FAIL, "H5Fclose");
+
+} /* end test_file_getname() */
+
+/****************************************************************
+**
+**  test_file_double_root_open(): low-level file test routine.
+**      This test checks whether opening the root group from two
+**      different files works correctly.
+**
+*****************************************************************/
+static void
+test_file_double_root_open(void)
+{
+    hid_t file1_id, file2_id; 
+    hid_t grp1_id, grp2_id; 
+    herr_t ret;         /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing double root group open\n"));
+
+    file1_id = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(file1_id, FAIL, "H5Fcreate");
+    file2_id = H5Fopen (FILE1, H5F_ACC_RDONLY, H5P_DEFAULT);
+    CHECK(file2_id, FAIL, "H5Fopen");
+
+    grp1_id  = H5Gopen(file1_id, "/");
+    CHECK(grp1_id, FAIL, "H5Gopen");
+    grp2_id  = H5Gopen(file2_id, "/");
+    CHECK(grp2_id, FAIL, "H5Gopen");
+
+    /* Note "assymetric" close order */
+    ret = H5Gclose(grp1_id);
+    CHECK(ret, FAIL, "H5Gclose");
+    ret = H5Gclose(grp2_id);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    ret = H5Fclose(file1_id);
+    CHECK(ret, FAIL, "H5Fclose");
+    ret = H5Fclose(file2_id);
+    CHECK(ret, FAIL, "H5Fclose");
+} /* end test_file_double_root_open() */
+
+/****************************************************************
+**
+**  test_file_double_group_open(): low-level file test routine.
+**      This test checks whether opening the same group from two
+**      different files works correctly.
+**
+*****************************************************************/
+static void
+test_file_double_group_open(void)
+{
+    hid_t file1_id, file2_id; 
+    hid_t grp1_id, grp2_id; 
+    herr_t ret;         /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing double non-root group open\n"));
+
+    file1_id = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(file1_id, FAIL, "H5Fcreate");
+    file2_id = H5Fopen (FILE1, H5F_ACC_RDONLY, H5P_DEFAULT);
+    CHECK(file2_id, FAIL, "H5Fopen");
+
+    grp1_id  = H5Gcreate(file1_id, GRP_NAME, (size_t)0);
+    CHECK(grp1_id, FAIL, "H5Gcreate");
+    grp2_id  = H5Gopen(file2_id, GRP_NAME);
+    CHECK(grp2_id, FAIL, "H5Gopen");
+
+    /* Note "assymetric" close order */
+    ret = H5Gclose(grp1_id);
+    CHECK(ret, FAIL, "H5Gclose");
+    ret = H5Gclose(grp2_id);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    ret = H5Fclose(file1_id);
+    CHECK(ret, FAIL, "H5Fclose");
+    ret = H5Fclose(file2_id);
+    CHECK(ret, FAIL, "H5Fclose");
+} /* end test_file_double_group_open() */
+
+/****************************************************************
+**
+**  test_file_double_dataset_open(): low-level file test routine.
+**      This test checks whether opening the same dataset from two
+**      different files works correctly.
+**
+*****************************************************************/
+static void
+test_file_double_dataset_open(void)
+{
+    hid_t file1_id, file2_id; 
+    hid_t dset1_id, dset2_id; 
+    hid_t space_id; 
+    herr_t ret;         /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing double dataset open\n"));
+
+    file1_id = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(file1_id, FAIL, "H5Fcreate");
+    file2_id = H5Fopen (FILE1, H5F_ACC_RDONLY, H5P_DEFAULT);
+    CHECK(file2_id, FAIL, "H5Fopen");
+
+    /* Create dataspace for dataset */
+    space_id = H5Screate(H5S_SCALAR);
+    CHECK(space_id, FAIL, "H5Screate");
+
+    dset1_id  = H5Dcreate(file1_id, DSET_NAME, H5T_NATIVE_INT, space_id, H5P_DEFAULT);
+    CHECK(dset1_id, FAIL, "H5Dcreate");
+    dset2_id  = H5Dopen(file2_id, DSET_NAME);
+    CHECK(dset2_id, FAIL, "H5Dopen");
+
+    /* Close "supporting" dataspace */
+    ret = H5Sclose(space_id);
+    CHECK(ret, FAIL, "H5Sclose");
+
+    /* Note "assymetric" close order */
+    ret = H5Dclose(dset1_id);
+    CHECK(ret, FAIL, "H5Dclose");
+    ret = H5Dclose(dset2_id);
+    CHECK(ret, FAIL, "H5Dclose");
+
+    ret = H5Fclose(file1_id);
+    CHECK(ret, FAIL, "H5Fclose");
+    ret = H5Fclose(file2_id);
+    CHECK(ret, FAIL, "H5Fclose");
+} /* end test_file_double_dataset_open() */
+
+/****************************************************************
+**
+**  test_file_double_datatype_open(): low-level file test routine.
+**      This test checks whether opening the same named datatype from two
+**      different files works correctly.
+**
+*****************************************************************/
+static void
+test_file_double_datatype_open(void)
+{
+    hid_t file1_id, file2_id; 
+    hid_t type1_id, type2_id; 
+    herr_t ret;         /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing double dataset open\n"));
+
+    file1_id = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(file1_id, FAIL, "H5Fcreate");
+    file2_id = H5Fopen (FILE1, H5F_ACC_RDONLY, H5P_DEFAULT);
+    CHECK(file2_id, FAIL, "H5Fopen");
+
+    type1_id  = H5Tcopy(H5T_NATIVE_INT);
+    CHECK(type1_id, FAIL, "H5Tcopy");
+    ret  = H5Tcommit(file1_id, TYPE_NAME, type1_id);
+    CHECK(ret, FAIL, "H5Tcommit");
+    type2_id  = H5Topen(file2_id, TYPE_NAME);
+    CHECK(type2_id, FAIL, "H5Topen");
+
+    /* Note "assymetric" close order */
+    ret = H5Tclose(type1_id);
+    CHECK(ret, FAIL, "H5Tclose");
+    ret = H5Tclose(type2_id);
+    CHECK(ret, FAIL, "H5Tclose");
+
+    ret = H5Fclose(file1_id);
+    CHECK(ret, FAIL, "H5Fclose");
+    ret = H5Fclose(file2_id);
+    CHECK(ret, FAIL, "H5Fclose");
+} /* end test_file_double_dataset_open() */
+
 /****************************************************************
 **
 **  test_file(): Main low-level file I/O test routine.
-** 
+**
 ****************************************************************/
-void 
+void
 test_file(void)
 {
     /* Output message about test being performed */
@@ -1314,13 +1821,20 @@ test_file(void)
 
     test_file_create();		/* Test file creation(also creation templates)*/
     test_file_open();		/* Test file opening */
-#ifndef H5_NO_SHARED_WRITING 
+#ifndef H5_NO_SHARED_WRITING
     test_file_close();          /* Test file close behavior */
-#endif /* H5_NO_SHARED_WRITING */     
+#endif /* H5_NO_SHARED_WRITING */
     test_get_file_id();         /* Test H5Iget_file_id */
     test_file_perm();           /* Test file access permissions */
     test_file_freespace();      /* Test file free space information */
     test_file_ishdf5();         /* Test detecting HDF5 files correctly */
+    test_file_open_dot();       /* Test opening objects with "." for a name */
+    test_file_open_overlap();   /* Test opening files in an overlapping manner */
+    test_file_getname();        /* Test basic H5Fget_name() functionality */
+    test_file_double_root_open();       /* Test opening root group from two files works properly */
+    test_file_double_group_open();      /* Test opening same group from two files works properly */
+    test_file_double_dataset_open();    /* Test opening same dataset from two files works properly */
+    test_file_double_datatype_open();   /* Test opening same named datatype from two files works properly */
 }				/* test_file() */
 
 
