@@ -78,8 +78,6 @@ static herr_t list (hid_t group, const char *name, void *cd);
 static void display_type(hid_t type, int ind);
 static char *fix_name(const char *path, const char *base);
 
-hid_t thefile;
-char  *prefix;
 const char *progname="h5ls";
 int   d_status;
 
@@ -152,20 +150,19 @@ sym_insert(H5G_stat_t *sb, const char *name)
     /* Don't add it if the link count is 1 because such an object can only
      * have one name. */
     if (sb->nlink<2) return;
-    
+
     /* Extend the table */
     if (idtab_g.nobjs>=idtab_g.nalloc) {
- idtab_g.nalloc = MAX(256, 2*idtab_g.nalloc);
- idtab_g.obj = realloc(idtab_g.obj,
-         idtab_g.nalloc*sizeof(idtab_g.obj[0]));
+        idtab_g.nalloc = MAX(256, 2*idtab_g.nalloc);
+        idtab_g.obj = realloc(idtab_g.obj,
+            idtab_g.nalloc*sizeof(idtab_g.obj[0]));
     }
 
     /* Insert the entry */
     n = idtab_g.nobjs++;
     idtab_g.obj[n].id[0] = sb->objno[0];
     idtab_g.obj[n].id[1] = sb->objno[1];
-    idtab_g.obj[n].name = malloc(strlen(name)+1);
-    strcpy(idtab_g.obj[n].name, name);
+    idtab_g.obj[n].name = HDstrdup(name);
 }
 
 
@@ -189,7 +186,7 @@ static char *
 sym_lookup(H5G_stat_t *sb)
 {
     int  n;
-    
+
     if (sb->nlink<2) return NULL; /*only one name possible*/
     for (n=0; n<idtab_g.nobjs; n++) {
  if (idtab_g.obj[n].id[0]==sb->objno[0] &&
@@ -221,58 +218,58 @@ static int
 display_string(FILE *stream, const char *s, hbool_t escape_spaces)
 {
     int  nprint=0;
-    
+
     for (/*void*/; s && *s; s++) {
- switch (*s) {
- case '"':
-     if (stream) fprintf(stream, "\\\"");
-     nprint += 2;
-     break;
- case '\\':
-     if (stream) fprintf(stream, "\\\\");
-     nprint += 2;
-     break;
- case '\b':
-     if (stream) fprintf(stream, "\\b");
-     nprint += 2;
-     break;
- case '\f':
-     if (stream) fprintf(stream, "\\f");
-     nprint += 2;
-     break;
- case '\n':
-     if (stream) fprintf(stream, "\\n");
-     nprint += 2;
-     break;
- case '\r':
-     if (stream) fprintf(stream, "\\r");
-     nprint += 2;
-     break;
- case '\t':
-     if (stream) fprintf(stream, "\\t");
-     nprint += 2;
-     break;
- case ' ':
-     if (escape_spaces) {
-  if (stream) fprintf(stream, "\\ ");
-  nprint += 2;
-     } else {
-  if (stream) fprintf(stream, " ");
-  nprint++;
-     }
-     break;
- default:
-     if (isprint((int)*s)) {
-  if (stream) putc(*s, stream);
-  nprint++;
-     } else {
-  if (stream) {
-      fprintf(stream, "\\%03o", *((const unsigned char*)s));
-  }
-  nprint += 4;
-     }
-     break;
- }
+        switch (*s) {
+            case '"':
+                if (stream) fprintf(stream, "\\\"");
+                nprint += 2;
+                break;
+            case '\\':
+                if (stream) fprintf(stream, "\\\\");
+                nprint += 2;
+                break;
+            case '\b':
+                if (stream) fprintf(stream, "\\b");
+                nprint += 2;
+                break;
+            case '\f':
+                if (stream) fprintf(stream, "\\f");
+                nprint += 2;
+                break;
+            case '\n':
+                if (stream) fprintf(stream, "\\n");
+                nprint += 2;
+                break;
+            case '\r':
+                if (stream) fprintf(stream, "\\r");
+                nprint += 2;
+                break;
+            case '\t':
+                if (stream) fprintf(stream, "\\t");
+                nprint += 2;
+                break;
+            case ' ':
+                if (escape_spaces) {
+                    if (stream) fprintf(stream, "\\ ");
+                    nprint += 2;
+                } else {
+                    if (stream) fprintf(stream, " ");
+                    nprint++;
+                }
+                break;
+            default:
+                if (isprint((int)*s)) {
+                    if (stream) putc(*s, stream);
+                    nprint++;
+                } else {
+                    if (stream) {
+                        fprintf(stream, "\\%03o", *((const unsigned char*)s));
+                    }
+                    nprint += 4;
+                }
+                break;
+        }
     }
     return nprint;
 }
@@ -545,9 +542,9 @@ display_int_type(hid_t type, int ind)
     const char  *order_s=NULL;  /* byte order string */
     H5T_sign_t  sign;           /* sign scheme value */
     const char  *sign_s=NULL;   /* sign scheme string */
-    
+
     if (H5T_INTEGER!=H5Tget_class(type)) return FALSE;
-    
+
     /* Byte order */
     if (H5Tget_size(type)>1) {
  order = H5Tget_order(type);
@@ -576,7 +573,7 @@ display_int_type(hid_t type, int ind)
     } else {
  sign_s = " unknown-sign";
     }
-    
+
     /* Print size, order, and sign on first line, precision and padding
      * information on the subsequent lines */
     printf("%lu-bit%s%s integer",
@@ -615,9 +612,9 @@ display_float_type(hid_t type, int ind)
     const char  *norm_s=NULL;   /* normalization string */
     H5T_pad_t   pad;            /* internal padding value */
     const char  *pad_s=NULL;    /* internal padding string */
-    
+
     if (H5T_FLOAT!=H5Tget_class(type)) return FALSE;
-    
+
     /* Byte order */
     if (H5Tget_size(type)>1) {
  order = H5Tget_order(type);
@@ -658,7 +655,7 @@ display_float_type(hid_t type, int ind)
  norm_s = ", unknown normalization";
  break;
     }
-    printf("\n%*s(significant for %lu bit%s at bit %lu%s)", ind, "", 
+    printf("\n%*s(significant for %lu bit%s at bit %lu%s)", ind, "",
     (unsigned long)msize, 1==msize?"":"s", (unsigned long)mpos,
     norm_s);
     printf("\n%*s(exponent for %lu bit%s at bit %lu, bias is 0x%lx)",
@@ -715,7 +712,7 @@ display_cmpd_type(hid_t type, int ind)
     unsigned    nmembs;         /* number of members */
     int         n;              /* miscellaneous counters */
     unsigned    i;              /* miscellaneous counters */
-    
+
     if (H5T_COMPOUND!=H5Tget_class(type)) return FALSE;
     printf("struct {");
     nmembs=H5Tget_nmembers(type);
@@ -762,7 +759,7 @@ display_enum_type(hid_t type, int ind)
 {
     char        **name=NULL;    /* member names */
     unsigned char *value=NULL;  /* value array */
-    unsigned char *copy = NULL; /*a pointer to value array       */
+    unsigned char *copy = NULL; /* a pointer to value array */
     unsigned    nmembs;         /* number of members */
     int         nchars;         /* number of output characters */
     hid_t       super;          /* enum base integer type */
@@ -770,7 +767,7 @@ display_enum_type(hid_t type, int ind)
     size_t      dst_size;       /* destination value type size */
     unsigned    i;              /* miscellaneous counters */
     size_t j;
-        
+
     if (H5T_ENUM!=H5Tget_class(type)) return FALSE;
     nmembs = H5Tget_nmembers(type);
     assert(nmembs>0);
@@ -778,7 +775,7 @@ display_enum_type(hid_t type, int ind)
     printf("enum ");
     display_type(super, ind+4);
     printf(" {");
-    
+
     /* Determine what data type to use for the native values.  To simplify
      * things we entertain three possibilities:
      *  1. long_long -- the largest native signed integer
@@ -820,15 +817,15 @@ display_enum_type(hid_t type, int ind)
             for (j=0; j<dst_size; j++)
                 printf("%02x", value[i*dst_size+j]);
         } else if (H5T_SGN_NONE==H5Tget_sign(native)) {
-	    /*On SGI Altix(cobalt), wrong values were printed out with "value+i*dst_size"
-	     *strangely, unless use another pointer "copy".*/
-	    copy = value+i*dst_size;
+ 	    /*On SGI Altix(cobalt), wrong values were printed out with "value+i*dst_size"
+ 	     *strangely, unless use another pointer "copy".*/
+ 	    copy = value+i*dst_size;
             HDfprintf(stdout,"%"H5_PRINTF_LL_WIDTH"u",
             *((unsigned long_long*)((void*)copy)));
         } else {
-	    /*On SGI Altix(cobalt), wrong values were printed out with "value+i*dst_size"
-	     *strangely, unless use another pointer "copy".*/
-	    copy = value+i*dst_size;
+ 	    /*On SGI Altix(cobalt), wrong values were printed out with "value+i*dst_size"
+ 	     *strangely, unless use another pointer "copy".*/
+ 	    copy = value+i*dst_size;
             HDfprintf(stdout,"%"H5_PRINTF_LL_WIDTH"d",
             *((long_long*)((void*)copy)));
         }
@@ -869,7 +866,7 @@ display_string_type(hid_t type, int UNUSED ind)
     const char  *pad_s=NULL;
     H5T_cset_t  cset;
     const char  *cset_s=NULL;
-    
+
     if (H5T_STRING!=H5Tget_class(type)) return FALSE;
 
     /* Padding */
@@ -969,7 +966,7 @@ display_reference_type(hid_t type, int UNUSED ind)
  printf("%lu-byte unknown reference",
         (unsigned long)H5Tget_size(type));
     }
-    
+
     return TRUE;
 }
 
@@ -995,7 +992,7 @@ display_opaque_type(hid_t type, int ind)
 {
     char *tag;
     size_t size;
-    
+
     if (H5T_OPAQUE!=H5Tget_class(type)) return FALSE;
 
     size = H5Tget_size(type);
@@ -1028,7 +1025,7 @@ static hbool_t
 display_vlen_type(hid_t type, int ind)
 {
     hid_t       super;
-    
+
     if (H5T_VLEN!=H5Tget_class(type)) return FALSE;
 
     printf("variable length of\n%*s", ind+4, "");
@@ -1086,7 +1083,7 @@ display_array_type(hid_t type, int ind)
     } else {
         fputs(" [SCALAR]", stdout);
     }
-    
+
 
     /* Print parent type */
     putchar(' ');
@@ -1095,7 +1092,7 @@ display_array_type(hid_t type, int ind)
     H5Tclose(super);
     return TRUE;
 }
-      
+
 /*-------------------------------------------------------------------------
  * Function: display_bitfield_type
  *
@@ -1167,7 +1164,7 @@ display_type(hid_t type, int ind)
 {
     H5T_class_t  data_class = H5Tget_class(type);
     H5G_stat_t  sb;
-    
+
     /* Bad data type */
     if (type<0) {
  printf("<ERROR>");
@@ -1184,7 +1181,7 @@ display_type(hid_t type, int ind)
      printf("shared ");
  }
     }
-    
+
     /* Print the type */
     if ((!simple_output_g && display_native_type(type, ind)) ||
  display_ieee_type(type, ind) ||
@@ -1232,7 +1229,7 @@ dump_dataset_values(hid_t dset)
     h5dump_t  info;
     char  string_prefix[64];
     static char         fmt_double[16], fmt_float[16];
- 
+
     /* Set to all default values and then override */
     memset(&info, 0, sizeof info);
 
@@ -1243,7 +1240,7 @@ dump_dataset_values(hid_t dset)
  info.line_multi_new = 0;
  info.line_pre  = "        ";
  info.line_cont = "         ";
- 
+
  info.arr_pre = "";
  info.arr_suf = "";
  info.arr_sep = " ";
@@ -1253,10 +1250,10 @@ dump_dataset_values(hid_t dset)
  info.cmpd_sep = " ";
 
  if (label_g) info.cmpd_name = "%s=";
- 
+
  info.elmt_suf1 = " ";
  info.str_locale = ESCAPE_HTML;
- 
+
     } else {
  info.idx_fmt = "(%s)";
  info.line_ncols = width_g;
@@ -1275,15 +1272,15 @@ dump_dataset_values(hid_t dset)
 
     info.dset_format =  "DSET-%lu:%lu:%lu:%lu-";
     info.dset_hidefileno = 0;
-    
+
     info.obj_format = "-%lu:%lu:%lu:%lu";
     info.obj_hidefileno = 0;
-    
+
     info.dset_blockformat_pre = "%sBlk%lu: ";
     info.dset_ptformat_pre = "%sPt%lu: ";
-    
+
     info.line_indent = "";
-    
+
     if (hexdump_g) {
         /* Print all data in hexadecimal format if the `-x' or `--hexdump'
          * command line switch was given. */
@@ -1299,8 +1296,8 @@ dump_dataset_values(hid_t dset)
  info.line_pre = string_prefix;
  info.line_suf = "\"";
     }
-    
-    /* Print all the values. */    
+
+    /* Print all the values. */
     printf("    Data:\n");
     if (h5tools_dump_dset(stdout, &info, dset, -1, NULL, -1) < 0) {
  printf("        Unable to print data.\n");
@@ -1383,7 +1380,7 @@ list_attr (hid_t obj, const char *attr_name, void UNUSED *op_data)
             info.line_pre  = "               ";
             info.line_cont = "                ";
             info.str_repeat = 8;
-            
+
         } else {
             printf("        Data:\n");
             info.idx_fmt = "(%s)";
@@ -1391,7 +1388,7 @@ list_attr (hid_t obj, const char *attr_name, void UNUSED *op_data)
             info.line_cont = "            %s  ";
             info.str_repeat = 8;
         }
-        
+
         info.line_ncols = width_g;
         if (label_g) info.cmpd_name = "%s=";
         if (string_g && 1==H5Tget_size(type) &&
@@ -1421,16 +1418,16 @@ list_attr (hid_t obj, const char *attr_name, void UNUSED *op_data)
             if (H5Aread(attr, p_type, buf)>=0)
                h5tools_dump_mem(stdout, &info, attr, p_type, space, buf, -1);
             free(buf);
-            H5Tclose(p_type); 
+            H5Tclose(p_type);
         }
-            
+
         H5Sclose(space);
         H5Tclose(type);
         H5Aclose(attr);
     } else {
         putchar('\n');
     }
-    
+
     return 0;
 }
 
@@ -1525,7 +1522,7 @@ dataset_list2(hid_t dset, const char UNUSED *name)
     int         n, max_len;     /* max extern file name length */
     double      utilization;    /* percent utilization of storage */
     int   i;
-    
+
     if (verbose_g>0) {
  dcpl = H5Dget_create_plist(dset);
  space = H5Dget_space(dset);
@@ -1552,14 +1549,14 @@ dataset_list2(hid_t dset, const char UNUSED *name)
         (unsigned long)used, 1==used?"":"s");
  if (used>0) {
 #ifdef WIN32
-    utilization = (hssize_t)total*100.0 /(hssize_t)used;
+    utilization = (hssize_t)total * 100.0 / (hssize_t)used;
 #else
     utilization = (total*100.0)/used;
 #endif
      printf(", %1.2f%% utilization", utilization);
  }
  putchar('\n');
- 
+
  /* Print information about external strorage */
  if ((nf = H5Pget_external_count(dcpl))>0) {
      for (i=0, max_len=0; i<nf; i++) {
@@ -1659,10 +1656,10 @@ static herr_t
 group_list2(hid_t grp, const char *name)
 {
     iter_t iter;
-    
+
     if (recursive_g) {
- iter.container = name;
- H5Giterate(grp, ".", NULL, list, &iter);
+        iter.container = name;
+        H5Giterate(grp, ".", NULL, list, &iter);
     }
     return 0;
 }
@@ -1720,7 +1717,7 @@ static hid_t
 link_open(hid_t location, const char *name)
 {
     char buf[64];
-    
+
     if (H5Gget_linkval (location, name, sizeof(buf), buf)<0) return -1;
     if (NULL==HDmemchr(buf, 0, sizeof(buf))) {
  strcpy(buf+sizeof(buf)-4, "...");
@@ -1760,90 +1757,91 @@ list (hid_t group, const char *name, void *_iter)
     herr_t status;
     iter_t *iter = (iter_t*)_iter;
     int  n;
-    
+
     /* Print the object name, either full name or base name */
     fullname = fix_name(iter->container, name);
     if (fullname_g) {
- n = display_string(stdout, fullname, TRUE);
- printf("%*s ", MAX(0, 24-n), "");
+        n = display_string(stdout, fullname, TRUE);
+        printf("%*s ", MAX(0, 24-n), "");
     } else {
- n = display_string(stdout, name, TRUE);
- printf("%*s ", MAX(0, 24-n), "");
+        n = display_string(stdout, name, TRUE);
+        printf("%*s ", MAX(0, 24-n), "");
     }
 
     /* Get object information */
     H5E_BEGIN_TRY {
- status = H5Gget_objinfo(group, name, FALSE, &sb);
+        status = H5Gget_objinfo(group, name, FALSE, &sb);
     } H5E_END_TRY;
     if (status<0) {
- puts("**NOT FOUND**");
- return 0;
+        puts("**NOT FOUND**");
+        return 0;
     } else if (sb.type<0 || sb.type>=H5G_NTYPES) {
- printf("Unknown type(%d)", sb.type);
- sb.type = H5G_UNKNOWN;
+        printf("Unknown type(%d)", sb.type);
+        sb.type = H5G_UNKNOWN;
     }
     if (sb.type>=0 && dispatch_g[sb.type].name) {
- fputs(dispatch_g[sb.type].name, stdout);
+        fputs(dispatch_g[sb.type].name, stdout);
     }
 
     /* If the object has already been printed then just show the object ID
      * and return. */
     if ((s=sym_lookup(&sb))) {
- printf(", same as ");
- display_string(stdout, s, TRUE);
- printf("\n");
- goto done;
+        printf(", same as ");
+        display_string(stdout, s, TRUE);
+        printf("\n");
+        goto done;
     } else {
- sym_insert(&sb, fullname);
+        sym_insert(&sb, fullname);
     }
-    
+
     /* Open the object.  Not all objects can be opened.  If this is the case
      * then return right away. */
     if (sb.type>=0 &&
- (NULL==dispatch_g[sb.type].open ||
-  (obj=(dispatch_g[sb.type].open)(group, name))<0)) {
- printf(" *ERROR*\n");
- goto done;
+            (NULL==dispatch_g[sb.type].open ||
+            (obj=(dispatch_g[sb.type].open)(group, name))<0)) {
+        printf(" *ERROR*\n");
+        goto done;
     }
-    
-    /* List the first line of information for the object. */    
+
+    /* List the first line of information for the object. */
     if (sb.type>=0 && dispatch_g[sb.type].list1) {
- (dispatch_g[sb.type].list1)(obj);
+        (dispatch_g[sb.type].list1)(obj);
     }
     putchar('\n');
-    
+
     /* Show detailed information about the object, beginning with information
      * which is common to all objects. */
     if (verbose_g>0 && H5G_LINK!=sb.type) {
- if (sb.type>=0) H5Aiterate(obj, NULL, list_attr, NULL);
+        if (sb.type>=0)
+            H5Aiterate(obj, NULL, list_attr, NULL);
  printf("    %-10s %lu:%lu:%lu:%lu\n", "Location:",
         sb.fileno[1], sb.fileno[0], sb.objno[1], sb.objno[0]);
- printf("    %-10s %u\n", "Links:", sb.nlink);
+        printf("    %-10s %u\n", "Links:", sb.nlink);
         if (sb.mtime>0) {
             if (simple_output_g) tm=gmtime(&(sb.mtime));
             else tm=localtime(&(sb.mtime));
             if (tm) {
-     strftime(buf, sizeof(buf), "%Y-%m-%d %H:%M:%S %Z", tm);
-     printf("    %-10s %s\n", "Modified:", buf);
- }
- }
- comment[0] = '\0';
- H5Gget_comment(group, name, sizeof(comment), comment);
- strcpy(comment+sizeof(comment)-4, "...");
- if (comment[0]) {
-     printf("    %-10s \"", "Comment:");
-     display_string(stdout, comment, FALSE);
-     puts("\"");
- }
+                strftime(buf, sizeof(buf), "%Y-%m-%d %H:%M:%S %Z", tm);
+                printf("    %-10s %s\n", "Modified:", buf);
+            }
+        }
+        comment[0] = '\0';
+        H5Gget_comment(group, name, sizeof(comment), comment);
+        strcpy(comment+sizeof(comment)-4, "...");
+        if (comment[0]) {
+            printf("    %-10s \"", "Comment:");
+            display_string(stdout, comment, FALSE);
+            puts("\"");
+        }
     }
     if (sb.type>=0 && dispatch_g[sb.type].list2) {
- (dispatch_g[sb.type].list2)(obj, fullname);
+        (dispatch_g[sb.type].list2)(obj, fullname);
     }
-    
-    /* Close the object. */    
- done:
+
+    /* Close the object. */
+done:
     if (sb.type>=0 && obj>=0 && dispatch_g[sb.type].close) {
- (dispatch_g[sb.type].close)(obj);
+        (dispatch_g[sb.type].close)(obj);
     }
     if (fullname) free(fullname);
     return 0;
@@ -1871,25 +1869,28 @@ list (hid_t group, const char *name, void *_iter)
 static char *
 fix_name(const char *path, const char *base)
 {
-    size_t n = (path?strlen(path):0) + (base?strlen(base):0) + 3;
-    char *s = malloc(n), prev='\0';
-    int  len=0;
+    size_t n = (path ? HDstrlen(path) : 0) + (base ? HDstrlen(base) : 0) + 3;
+    char *s = HDmalloc(n), prev='\0';
+    size_t len = 0;
 
     if (path) {
- /* Path, followed by slash */
- for (/*void*/; *path; path++) {
-     if ('/'!=*path || '/'!=prev) prev = s[len++] = *path;
- }
- if ('/'!=prev) prev = s[len++] = '/';
+        /* Path, followed by slash */
+        for (/*void*/; *path; path++)
+            if ('/'!=*path || '/'!=prev)
+                prev = s[len++] = *path;
+        if ('/' != prev)
+            prev = s[len++] = '/';
     }
 
     if (base) {
- /* Base name w/o trailing slashes */
- const char *end = base + strlen(base);
- while (end>base && '/'==end[-1]) --end;
- for (/*void*/; base<end; base++) {
-     if ('/'!=*base || '/'!=prev) prev = s[len++] = *base;
- }
+        /* Base name w/o trailing slashes */
+        const char *end = base + HDstrlen(base);
+        while (end > base && '/' == end[-1])
+            --end;
+
+        for (/*void*/; base < end; base++)
+            if ('/' != *base || '/' != prev)
+                prev = s[len++] = *base;
     }
 
     s[len] = '\0';
@@ -2001,7 +2002,7 @@ static void
 leave(int ret)
 {
     h5tools_close();
-    
+
     exit(ret);
 }
 
@@ -2076,7 +2077,7 @@ main (int argc, const char *argv[])
         } else if (!strcmp(argv[argno], "--full")) {
             fullname_g = TRUE;
         } else if (!strcmp(argv[argno], "--group")) {
-            grp_literal_g = TRUE; 
+            grp_literal_g = TRUE;
         } else if (!strcmp(argv[argno], "--label")) {
             label_g = TRUE;
         } else if (!strcmp(argv[argno], "--recursive")) {
